"""
Custom configurations for emails of no particular category.
"""
from epstein_files.documents.config.categories.crypto import VALAR_FUND
from epstein_files.documents.documents.categories import Interesting, Neutral
from epstein_files.documents.config.config_builder import (WOLFF_EPSTEIN_ARTICLE_DRAFT,
     binant_redacted, shaher_murder_email)
from epstein_files.documents.config.doc_cfg import DEFAULT_TRUNCATE_TO, NO_TRUNCATE, SHORT_TRUNCATE_TO, DocCfg, EmailCfg
from epstein_files.documents.emails.constants import FLIGHT_IN_2012_PEOPLE, IRAN_DEAL_RECIPIENTS, TRIVERS_CCS
from epstein_files.util.helpers.string_helper import join_truthy, quote
from epstein_files.people.names import *
from epstein_files.util.constant.strings import *

OTHER_FILES_PFX = 'OTHER_FILES_'
PARTICIPANTS_FIELD = 'Participants: field'


########################################################################################################
################################################ EMAILS ################################################
########################################################################################################

# Atribution reasons
BOLOTOVA_REASON = 'Same signature style as 029020 ("--" followed by "Sincerely Renata Bolotova")'
DROKOVA_TIMING_REASON = 'timing, subject (interviews/articles), and sequential ID'
KATHY_REASON = 'from "Kathy" about dems, sent from iPad'
LARRY_REASON = 'Planes discussion signed "Larry"'
LINDA_STONE_ATTRIBUTION = '"iPhone word substitution" in signature, which is traced back to "Linda, thanks" in EFTA00961792'
PAULA_REASON = 'signature of "Sent via BlackBerry from T-Mobile"'
SENT_FROM_SOON_YI = '"Sent from Soon-Yi\'s iPhone"'
SNEAKY_DOG = '"sneaky dog"'
SINCERELY_SNEAKY = f'{SNEAKY_DOG} + "Sincerely"'

# Descriptions
ALLEGED_KARIM_WADE = f"allegedly corrupt Senegalese politician {KARIM_WADE}"
IS_IT_ROGER_STONE = "is the 'roger' Epstein is trying to meet Roger Stone?"
VALAR_MEETING = f"meeting with {PETER_THIEL}'s {VALAR_VENTURES} fund"


EMAILS_CONFIG = [
    # TODO: 026294 and 026296 might also be Ittihadieh based on timing
    EmailCfg(id='032436', author=ALIREZA_ITTIHADIEH, author_reason='signature'),
    EmailCfg(id='032543', author=ANAS_ALRASHEED, author_reason='Later reply 033000 has quote'),
    EmailCfg(id='026167', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032571', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032573', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032575', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032577', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032579', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032582', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032585', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032588', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032591', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032595', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032599', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032611', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='023661', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032616', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032622', author=ANAS_ALRASHEED, author_reason='name visible in 033022 reply'),
    EmailCfg(id='032628', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='032629', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='032631', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026168', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026170', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026173', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026176', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026180', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026184', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026188', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026193', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026198', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026210', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='026204', author=ANAS_ALRASHEED, author_reason='name visible in 026180 reply'),
    EmailCfg(id='032660', author=ANAS_ALRASHEED, author_reason='name visible in 029113 reply'),
    EmailCfg(id='032663', author=ANAS_ALRASHEED, author_reason='name visible in 029113 reply'),
    EmailCfg(id='032667', author=ANAS_ALRASHEED, author_reason='name visible in 029113 reply'),
    EmailCfg(id='032672', author=ANAS_ALRASHEED, author_reason='name visible in 029113 reply'),
    EmailCfg(id='032676', author=ANAS_ALRASHEED, author_reason='name visible in 029113 reply'),
    EmailCfg(id='026237', author=ANAS_ALRASHEED, author_reason='name visible in 029113 reply'),
    EmailCfg(id='032682', author=ANAS_ALRASHEED, author_reason='name visible in 029113 reply'),
    EmailCfg(id='032542', author=ANAS_ALRASHEED, author_uncertain='discussion of Kuwait and timing'),
    EmailCfg(id='026078', author=ANAS_ALRASHEED, author_uncertain='discussion of Kuwait and timing'),
    EmailCfg(id='026080', author=ANAS_ALRASHEED, author_uncertain='discussion of Kuwait and timing'),
    EmailCfg(id='026083', author=ANAS_ALRASHEED, author_uncertain='discussion of Kuwait and timing'),
    EmailCfg(id='026086', author=ANAS_ALRASHEED, author_uncertain='discussion of Kuwait and timing'),
    EmailCfg(id='026090', author=ANAS_ALRASHEED, author_uncertain='discussion of Kuwait and timing'),
    EmailCfg(id='026064', author=ARIANE_DE_ROTHSCHILD, author_reason='signature'),
    EmailCfg(id='026069', author=ARIANE_DE_ROTHSCHILD, author_reason='signature'),
    EmailCfg(id='030741', author=ARIANE_DE_ROTHSCHILD, author_reason='signature'),
    EmailCfg(id='026018', author=ARIANE_DE_ROTHSCHILD, author_reason='signature'),
    EmailCfg(id='EFTA01744418', author=ARIANE_DE_ROTHSCHILD, author_reason='signature'),
    EmailCfg(
        id='029504',
        author='Audrey/Aubrey Raimbault (???)',
        author_reason='based on "GMI" in signature, a company registered by "Aubrey Raimbault"',
    ),
    EmailCfg(
        id='033316',
        author=AZIZA_ALAHMADI,
        author_reason='"Regards, Aziza" at bottom',
        fwded_text_after='Transcript: Phone call between President',
    ),
    EmailCfg(id='033328', author=AZIZA_ALAHMADI, author_reason='"Regards, Aziza" at bottom'),
    EmailCfg(
        id='031215',
        author=BARBRO_C_EHNBOM,
        duplicate_ids=['026745'],
        dupe_type='redacted',
        comment="the same except for 'your Anna!'. author must be specified because email address is redacted in 026745 so it needs the config",
    ),
    EmailCfg(id='019446', author=CHRISTINA_GALBRAITH, author_reason='from "Christina media/PR"'),
    EmailCfg(
        id='026624',
        author=DARREN_INDYKE,
        date='2016-10-01 16:40:00',
        duplicate_ids=['031708'],
        recipients=[JEFFREY_EPSTEIN],
        subject='Donald Trump Rape Lawsuit Refiled With New Witness I Law News',
    ),
    EmailCfg(
        id='031278',
        actual_text='',
        author_reason='Quoted replies are in 019109',
        author=DARREN_INDYKE,
        comment='Hoffenberg',
        date='2016-08-17 11:26:00',
        description="heavily redacted email, quoted replies are from Steven Hoffenberg about James Patterson's book",
        recipients=["Charles Michael"],
        subject='FW: Privileged and Confidential - Fwd: JAMES PATTERSON NEW BOOK TELLING FEDS COVER UP OF BILLIONAIRE JEFF EPSTEIN CHILD RAPES RELEASE DATE OCT 10 2016 STEVEN HOFFENBERG IS ON THE BOOK WRITING TEAM !!!!',
        truncate_to=2500,
    ),
    EmailCfg(id='026290', author=DAVID_SCHOEN, author_reason='signature'),
    EmailCfg(id='031339', author=DAVID_SCHOEN, author_reason='signature'),
    EmailCfg(id='031492', author=DAVID_SCHOEN, author_reason='signature'),
    EmailCfg(id='031560', author=DAVID_SCHOEN, author_reason='signature'),
    EmailCfg(id='026287', author=DAVID_SCHOEN, author_reason='signature'),
    EmailCfg(id='033419', author=DAVID_SCHOEN, author_reason='signature'),
    EmailCfg(
        id='EFTA02442672',
        author=DAVID_STERN,
        author_reason=f"{ASIA_GATEWAY} + 'D.' in signature",
        description="Bank Leumi would get in trouble for helping Americans avoid taxes a few years after this",
    ),
    EmailCfg(id='EFTA01775500', author=DAVID_STERN, author_reason='in quoted reply', description=f'"PA" is probably {PRINCE_ANDREW}'),
    EmailCfg(id='EFTA01862308', author=DAVID_STERN, author_uncertain='timing + David rowland'),
    EmailCfg(id='EFTA02410642', description=f'"PA" is probably {PRINCE_ANDREW}'),
    EmailCfg(id='EFTA02570707', author=DAVID_STERN, author_uncertain='in quoted reply', truncate_to=NO_TRUNCATE),
    EmailCfg(id='031460', author=EDWARD_JAY_EPSTEIN, author_reason='quoted reply has edwardjayepstein.com', is_fwded_article=True),
    EmailCfg(
        id='030475',
        author_reason='Next Management LLC legal signature',
        author=FAITH_KATES,
        duplicate_ids=['030575'],
        dupe_type='redacted',
    ),
    EmailCfg(id='026547', author=GERALD_BARTON, recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(id='029969', author=GWENDOLYN_BECK, author_reason='signature "Longevity & Successful Aging"'),
    EmailCfg(id='029968', author=GWENDOLYN_BECK, author_reason='signature "beckresearchlabs.com"', duplicate_ids=['031120']),
    EmailCfg(id='029970', author=GWENDOLYN_BECK, author_reason='signed "Longevity & Successful Aging"', truncate_to=400),
    EmailCfg(id='029960', author=GWENDOLYN_BECK, author_reason='signature "Beck Center for Longevity & Aging"', truncate_to=498),
    EmailCfg(id='029959', author=GWENDOLYN_BECK, author_reason='signature "Beck Center for Longevity & Aging"'),
    EmailCfg(id='029958', author=GWENDOLYN_BECK, author_reason='widely reported'),
    EmailCfg(id='033360', author=HENRY_HOLT, author_reason='in signature'),
    EmailCfg(id='033384', author=JACK_GOLDBERGER, author_uncertain='Might be Paul Prosperi?'),
    EmailCfg(id='026024', author=JEAN_HUGUEN, author_reason='signature'),
    EmailCfg(id='021823', author=JEAN_LUC_BRUNEL, author_reason='reply', truncate_to=900),
    EmailCfg(id='031624', author=JEFFREY_EPSTEIN),
    EmailCfg(id='018726', author=JEFFREY_EPSTEIN, date='2018-06-08 08:36:00'),
    EmailCfg(id='032283', author=JEFFREY_EPSTEIN, date='2016-09-14 08:04:00'),
    EmailCfg(id='026943', author=JEFFREY_EPSTEIN, recipients=[RICHARD_KAHN], date='2019-05-22 05:47:00'),
    EmailCfg(
        id='023208',
        # author=JEFFREY_EPSTEIN,
        # description="very long email chain about Leon Black's finances and things like Gratitude America",
        duplicate_ids=['023291'],
        # fwded_text_after='Date: Tue, Oct 27',
        # recipients=[BRAD_WECHSLER, MELANIE_SPINELLA],
        # truncate_to=NO_TRUNCATE,
    ),
    EmailCfg(
        id='032214',
        actual_text='Agreed',
        author_reason='Quoted reply has signature',
        author=JEFFREY_EPSTEIN,
        recipients=[MIROSLAV_LAJCAK],
    ),
    EmailCfg(id='029582', author=JEFFREY_EPSTEIN, recipients=[RENATA_BOLOTOVA], author_reason=BOLOTOVA_REASON),
    EmailCfg(id='030997', author=JEFFREY_EPSTEIN, actual_text='call back'),
    EmailCfg(id='028770', author=JEFFREY_EPSTEIN, actual_text='call me now'),
    EmailCfg(id='031826', author=JEFFREY_EPSTEIN, actual_text='I have', truncate_to=350),
    EmailCfg(id='030768', author=JEFFREY_EPSTEIN, actual_text='ok'),
    EmailCfg(id='022938', author=JEFFREY_EPSTEIN, actual_text='what do you suggest?'),
    EmailCfg(
        id='031791',
        author=JESSICA_CADWELL,
        author_reason='signature',
        truncate_to=NO_TRUNCATE,
        comment='First email in Jessica Cadwell chain about service of legal documents',
    ),
    EmailCfg(
        id='028850',
        description='Joi Ito reaching out to Epstein for an immediate phone call after news about illicit Russian money',
        duplicate_ids=['028851'],
        dupe_type='quoted',
    ),
    EmailCfg(
        id='028848',
        description='Joi Ito reaching out to Epstein for an immediate phone call after news about illicit Russian money',
        duplicate_ids=['028849'],
        dupe_type='quoted',
    ),
    EmailCfg(id='028507', author=JONATHAN_FARKAS, author_reason='reply signed "best Jonathan"'),
    EmailCfg(id='033282', author=JONATHAN_FARKAS, author_reason='reply signed "thanks Jonathan"', duplicate_ids=['033484']),
    EmailCfg(id='033582', author=JONATHAN_FARKAS, author_reason='reply', duplicate_ids=['032389']),
    EmailCfg(id='033203', author=JONATHAN_FARKAS, author_reason='reply', duplicate_ids=['033581']),
    EmailCfg(id='032052', author=JONATHAN_FARKAS, author_reason='reply', duplicate_ids=['031732']),
    EmailCfg(id='033490', author=JONATHAN_FARKAS, author_reason='signature', duplicate_ids=['032531']),
    EmailCfg(id='032224', author=KATHRYN_RUEMMLER, recipients=[JEFFREY_EPSTEIN], author_reason='reply'),
    EmailCfg(id='032386', author=KATHRYN_RUEMMLER, author_uncertain=KATHY_REASON),
    EmailCfg(id='032727', author=KATHRYN_RUEMMLER, author_uncertain=KATHY_REASON),
    EmailCfg(id='030478', author=LANDON_THOMAS),
    EmailCfg(id='029013', author=LARRY_SUMMERS, recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(id='029196', author=LAWRENCE_KRAUSS, recipients=[JEFFREY_EPSTEIN], actual_text='Talk in 40?'),
    EmailCfg(id='033593', author=LAWRANCE_VISOSKI, author_reason='signature', truncate_to=NO_TRUNCATE, comment='visoski email about planes'),
    EmailCfg(id='033370', author=LAWRANCE_VISOSKI, author_reason=LARRY_REASON),
    EmailCfg(id='033495', author=LAWRANCE_VISOSKI, author_reason=LARRY_REASON),
    EmailCfg(id='033487', author=LAWRANCE_VISOSKI, recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(
        id='029977',
        author=LAWRANCE_VISOSKI,
        recipients=[JEFFREY_EPSTEIN, DARREN_INDYKE, LESLEY_GROFF, RICHARD_KAHN] + FLIGHT_IN_2012_PEOPLE,
        author_reason=LARRY_REASON,
        duplicate_ids=['031129'],
    ),
    EmailCfg(id='027046', author=LAWRANCE_VISOSKI, duplicate_ids=['028789']),
    EmailCfg(id='033488', author=LAWRANCE_VISOSKI, duplicate_ids=['033154']),
    EmailCfg(id='033309', author=LINDA_STONE, author_reason='"Co-authored with iPhone autocorrect"'),
    EmailCfg(id='017581', author=LISA_RANDALL, author_reason='reply header'),
    EmailCfg(id='026609', author='Mark Green', author_reason='Actually a fwd, Mark Green is in signature'),
    EmailCfg(id='030472', author=MARTIN_WEINBERG, author_uncertain='Maybe. in reply'),
    EmailCfg(
        id='032564',
        author_reason='follow up to 032563 about huffpo article with link',
        author=MASHA_DROKOVA,
        description='an archived version of the HuffPost link is here: https://archive.is/hJxT3 '
    ),
    EmailCfg(id='031544', author=MASHA_DROKOVA, author_reason='follow up to 032563 about huffpo article with link'),
    EmailCfg(id='032605', author=MASHA_DROKOVA, author_reason="re: PR interview, 031544 says she'll be in NY at that time"),
    EmailCfg(id='032606', author=MASHA_DROKOVA, author_reason="re: PR interview, 031544 says she'll be in NY at that time"),
    EmailCfg(id='032607', author=MASHA_DROKOVA, author_reason="re: PR interview, 031544 says she'll be in NY at that time"),
    EmailCfg(id='032609', author=MASHA_DROKOVA, author_reason="re: PR interview, 031544 says she'll be in NY at that time"),
    EmailCfg(id='032563', author=MASHA_DROKOVA, author_reason='replied to in 033014'),
    EmailCfg(id='032604', author=MASHA_DROKOVA, author_uncertain=DROKOVA_TIMING_REASON),
    EmailCfg(id='032581', author=MASHA_DROKOVA, author_uncertain=DROKOVA_TIMING_REASON),
    EmailCfg(id='030235', author=MELANIE_WALKER, author_reason='in fwd'),
    EmailCfg(id='032343', author=MELANIE_WALKER, author_reason='name seen in later reply 032346'),
    EmailCfg(id='032212', author=MIROSLAV_LAJCAK, author_reason='signature'),
    EmailCfg(id='021814', author=NADIA_MARCINKO, author_reason='reply'),
    EmailCfg(id='021808', author=NADIA_MARCINKO, author_reason='reply', truncate_to=NO_TRUNCATE),
    EmailCfg(id='021818', author=NADIA_MARCINKO, author_reason='reply'),
    EmailCfg(id='022214', author=NADIA_MARCINKO, author_reason='Reply header'),
    EmailCfg(id='021811', author=NADIA_MARCINKO, author_reason='signature and email address in the message'),
    EmailCfg(id='028487', author=NORMAN_D_RAU, author_reason='Fwded from "to" address', duplicate_ids=['026612']),
    EmailCfg(
        id='024923',
        comment='krassner',
        duplicate_ids=['031973'],
        has_uninteresting_ccs=True,
        recipients=["George Krassner", "Nick Kazan", "Mrisman02", "Rebecca Risman", "Linda W. Grossman"],
    ),
    EmailCfg(id='032457', author=PAUL_KRASSNER, recipients=[JEFFREY_EPSTEIN, "Nancy Cain"]),
    EmailCfg(id='029981', author=PAULA_HEIL_FISHER, author_uncertain='name in reply + opera reference'),
    EmailCfg(id='030482', author=PAULA_HEIL_FISHER, author_uncertain=PAULA_REASON),
    EmailCfg(id='033383', author=PAUL_PROSPERI, author_reason='reply'),
    EmailCfg(
        id='012684',
        author=PAUL_PROSPERI,
        is_fwded_article=True,
        author_uncertain='one week after Epstein asked Prosperi for info on Kluge auction',
    ),
    EmailCfg(
        id='033561',
        author=PAUL_PROSPERI,
        duplicate_ids=['033157'],
        author_uncertain='Fwded mail sent to Prosperi. Might be Subotnick Stuart?',
    ),
    EmailCfg(id='031694', author=PEGGY_SIEGAL, author_uncertain='quoted'),
    EmailCfg(id='032219', author=PEGGY_SIEGAL, author_reason='Signed "Peggy"'),
    EmailCfg(id='029020', author=RENATA_BOLOTOVA, author_reason='signature'),
    EmailCfg(id='029605', author=RENATA_BOLOTOVA, author_reason=BOLOTOVA_REASON),
    EmailCfg(id='029606', author=RENATA_BOLOTOVA, author_reason=BOLOTOVA_REASON),
    EmailCfg(id='029604', author=RENATA_BOLOTOVA, author_reason='Continued in 239606 etc'),
    EmailCfg(
        id='033584',
        author=ROBERT_TRIVERS,
        recipients=[JEFFREY_EPSTEIN],
        author_reason='Refs paper by Trivers',
        duplicate_ids=['033169'],
    ),
    EmailCfg(id='026320', author=SEAN_BANNON, author_reason="From protonmail, Bannon wrote 'just sent from my protonmail' in 027067"),
    EmailCfg(id='029003', author=SOON_YI_PREVIN, author_reason=SENT_FROM_SOON_YI),
    EmailCfg(id='029005', author=SOON_YI_PREVIN, author_reason=SENT_FROM_SOON_YI),
    EmailCfg(id='029007', author=SOON_YI_PREVIN, author_reason=SENT_FROM_SOON_YI),
    EmailCfg(id='029010', author=SOON_YI_PREVIN, author_reason=SENT_FROM_SOON_YI),
    EmailCfg(id='032296', author=SOON_YI_PREVIN, author_reason=SENT_FROM_SOON_YI),
    EmailCfg(id='033292', author=SOON_YI_PREVIN, author_uncertain="mentions \"Woody's movie\""),
    EmailCfg(
        id='019109',
        author=STEVEN_HOFFENBERG,
        date='2016-08-11 09:36:01',
        description='looks like a memo from Charles Michael containing copy/paste of email contents?',
        recipients=["Players2"],
        subject='FW: Privileged and Confidential - Fwd: JAMES PATTERSON NEW BOOK TELLING FEDS COVER UP OF BILLIONAIRE JEFF EPSTEIN CHILD RAPES RELEASE DATE OCT 10 2016 STEVEN HOFFENBERG IS ON THE BOOK WRITING TEAM !!!!',
    ),
    EmailCfg(
        id='022396',
        author=SVETLANA_POZHIDAEVA,
        author_uncertain='https://x.com/FlippersUpNow/status/2022438575699018094',
        comment='Ukraine friend',
        is_interesting=True,
    ),
    EmailCfg(
        id='026620',
        author=TERRY_KAFKA,
        author_reason='ends with "Respectfully, terry"',
        duplicate_ids=['028482'],
        fwded_text_after='From: Mike Cohen',
        recipients=[JEFFREY_EPSTEIN, MARK_EPSTEIN, MICHAEL_BUCHHOLTZ] + IRAN_DEAL_RECIPIENTS,
        subject='Fw: The Iran Nuclear Deal',
    ),
    EmailCfg(id='029992', author=TERRY_KAFKA, author_reason='Quoted reply'),
    EmailCfg(id='029985', author=TERRY_KAFKA, author_reason='Quoted reply in 029992'),
    EmailCfg(id='020666', author=TERRY_KAFKA, author_reason="Ends with 'Terry'"),
    EmailCfg(id='033021', recipients=[ANAS_ALRASHEED], author_reason='visible in 033022'),
    EmailCfg(id='027063', recipients=[ANTHONY_BARRETT]),
    EmailCfg(id='030764', recipients=[ARIANE_DE_ROTHSCHILD], author_reason='reply'),
    EmailCfg(id='026431', recipients=[ARIANE_DE_ROTHSCHILD], author_reason='reply'),
    EmailCfg(id='EFTA00825164', recipients=[ARIANE_DE_ROTHSCHILD], author_reason='reply'),
    EmailCfg(id='032876', recipients=[CECILIA_STEEN], author_reason='unredacted in 032267'),
    EmailCfg(id='026466', recipients=[DIANE_ZIMAN], author_reason='Quoted reply'),
    EmailCfg(id='031607', recipients=[EDWARD_JAY_EPSTEIN], is_fwded_article=True, author_reason='quoted reply has edwardjayepstein.com'),
    EmailCfg(
        id='030525',
        recipients=[FAITH_KATES],
        author_reason='Reply in 030414 has Next Management LLC legal signature',
        duplicate_ids=['030581'],
    ),
    EmailCfg(
        id='025329',
        has_uninteresting_ccs=True,
        recipients=["George Krassner", "Nancy Cain", "Tom", "Marie Moneysmith", "Steven Gaydos", "Linda W. Grossman", "Holly Krassner Dawson", "Daniel Dawson", "Danny Goldberg", "Caryl Ratner", "Kevin Bright", "Michael Simmons", SAMUEL_LEFF, "Bob Fass", "Lynnie Tofte Fass", "Barb Cowles", "Lee Quarnstrom"],
    ),
    EmailCfg(
        id='033568',
        has_uninteresting_ccs=True,
        recipients=["George Krassner", "Daniel Dawson", "Danny Goldberg", "Tom", "Kevin Bright", "Walli Leff", "Michael Simmons", "Lee Quarnstrom", "Lanny Swerdlow", "Larry Sloman", "W&K", "Harry Shearer", "Jay Levin"],
        subject="Fwd: Daryl Cagle's Blog",
    ),
    EmailCfg(id='029962', recipients=[GWENDOLYN_BECK]),
    EmailCfg(id='026426', recipients=[JEAN_HUGUEN], author_reason='reply'),
    EmailCfg(id='030347', recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(id='033274', recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(id='032780', recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(id='033386', recipients=[JEFFREY_EPSTEIN, None], duplicate_ids=['033599']),
    EmailCfg(id='029324', recipients=[JEFFREY_EPSTEIN, "Jojo Fontanilla", "Lyn Fontanilla"]),
    EmailCfg(id='013482', recipients=[JEFFREY_EPSTEIN], is_fwded_article=True),
    EmailCfg(
        id='029558',
        author_reason='BCC',
        fwded_text_after='Creativity is central',
        recipients=[JEFFREY_EPSTEIN, KATHERINE_KEATING],
    ),
    EmailCfg(id='025589', recipients=[GORDON_GETTY, JEFFREY_EPSTEIN] + TRIVERS_CCS, author_reason='reply'),
    EmailCfg(
        id='031688',
        comment='Bill Siegel fwd of email about Hamas',
        is_fwded_article=True,
        recipients=[JEFFREY_EPSTEIN],
        recipient_uncertain=True,
    ),
    EmailCfg(id='033456', recipients=["Joel"], author_reason='reply'),
    EmailCfg(id='033458', recipients=["Joel"], author_reason='reply'),
    EmailCfg(id='033460', recipients=["Joel"], author_reason='reply'),
    EmailCfg(
        id='021090',
        recipients=[JONATHAN_FARKAS],
        author_reason='Reply to a message signed "jonathan" same as other Farkas emails',
        is_fwded_article=True,
    ),
    EmailCfg(id='033073', recipients=[KATHRYN_RUEMMLER], recipient_uncertain='to "Kathy" about dems, sent from iPad'),
    EmailCfg(id='032939', recipients=[KATHRYN_RUEMMLER], recipient_uncertain='to "Kathy" about dems, sent from iPad'),
    EmailCfg(id='030522', recipients=[LANDON_THOMAS], author_reason='reply header', is_fwded_article=True),
    EmailCfg(id='031413', recipients=[LANDON_THOMAS], author_reason='reply header'),
    EmailCfg(id='033591', recipients=[LAWRANCE_VISOSKI], author_reason='reply signature'),
    EmailCfg(id='027097', recipients=[LAWRANCE_VISOSKI], author_reason='reply signature', duplicate_ids=['028787']),
    EmailCfg(id='033466', recipients=[LAWRANCE_VISOSKI], author_reason='reply signature'),
    EmailCfg(id='022250', recipients=[LESLEY_GROFF], author_reason='reply'),
    EmailCfg(id='030242', recipients=[MARIANA_IDZKOWSKA], duplicate_ids=['032048'], dupe_type='redacted'),
    EmailCfg(id='033027', recipients=[MASHA_DROKOVA], author_reason="re: PR interview, 031544 says she'll be in NY at that time"),
    EmailCfg(id='033025', recipients=[MASHA_DROKOVA], recipient_uncertain=DROKOVA_TIMING_REASON),
    EmailCfg(id='030368', recipients=[MELANIE_SPINELLA], author_reason='Actually a self fwd from jeffrey to jeffrey'),
    EmailCfg(id='030369', recipients=[MELANIE_SPINELLA], author_reason='Actually a self fwd from jeffrey to jeffrey'),
    EmailCfg(id='030371', recipients=[MELANIE_SPINELLA], author_reason='Actually a self fwd from jeffrey to jeffrey'),
    EmailCfg(id='022258', recipients=[NADIA_MARCINKO], author_reason='Reply header'),
    EmailCfg(id='022193', recipients=[NADIA_MARCINKO], author_reason='reply'),
    EmailCfg(id='022197', recipients=[NADIA_MARCINKO], author_reason='reply'),
    EmailCfg(id='022190', recipients=[NADIA_MARCINKO], author_reason='reply'),
    EmailCfg(id='030572', recipients=[PAULA_HEIL_FISHER], recipient_uncertain='quoted in 030482'),
    EmailCfg(id='030506', recipients=[PAULA_HEIL_FISHER], recipient_uncertain=PAULA_REASON,),
    EmailCfg(id='030507', recipients=[PAULA_HEIL_FISHER], recipient_uncertain=PAULA_REASON,),
    EmailCfg(id='030508', recipients=[PAULA_HEIL_FISHER], recipient_uncertain=PAULA_REASON,),
    EmailCfg(id='030509', recipients=[PAULA_HEIL_FISHER], recipient_uncertain=PAULA_REASON,),
    EmailCfg(id='030096', recipients=[PETER_MANDELSON], author_reason='reply header'),
    EmailCfg(id='032951', recipients=[RAAFAT_ALSABBAGH, None], author_reason='Redacted'),
    EmailCfg(id='029581', recipients=[RENATA_BOLOTOVA], author_reason=BOLOTOVA_REASON),
    EmailCfg(id='019334', recipients=[STEVE_BANNON], author_reason='quoted reply'),
    EmailCfg(id='021106', recipients=[STEVE_BANNON], author_reason='reply'),
    # Quotes
    EmailCfg(id='029679', is_interesting=True, highlight_quote='his driver MAtt was the bag man', description="(re: Trump)"),
    EmailCfg(id='026505', is_interesting=True, highlight_quote='I know how dirty donald is'),
    EmailCfg(id='031659', is_interesting=True, highlight_quote='i have met some very bad people „ none as bad as trump'),
    EmailCfg(id='031326', is_interesting=True, highlight_quote='that dog that hasn\'t barked is trump'),
    EmailCfg(id='031451', is_interesting=True, highlight_quote='would you like photso of donald and girls in bikinis in my kitchen'),
    EmailCfg(id='031596', is_interesting=True, highlight_quote='would you like photso of donald and girls in bikinis in my kitchen', truncate_to=500),
    EmailCfg(id='031601', is_interesting=True, highlight_quote='Old gf i gave to donald', truncate_to=2000),
    EmailCfg(id='EFTA00832976', is_interesting=True, highlight_quote="i represent the rothschilds"),
    # actual_text
    EmailCfg(id='029344', actual_text='I thought of you when I read this article. Was this your idea? Alan', is_fwded_article=True),
    EmailCfg(id='032358', actual_text=REDACTED),
    # description
    EmailCfg(id='030430', description=f"{STEVE_BANNON} was involved in the Biosphere project"),
    EmailCfg(id='031036', description=f'{BARBRO_C_EHNBOM} related donation / Swedish girls discussion', is_interesting=True),
    EmailCfg(id='030737', description='Bannon says there is a "crazed jihad" against Epstein', is_interesting=True),
    EmailCfg(id='030738', description='Bannon tells Epstein "somebody big has u in the gunsights"', is_interesting=True),
    EmailCfg(id='032458', description='discussion of acquiring pieces for Epstein\'s art collection', truncate_to=NO_TRUNCATE),
    EmailCfg(id='032946', description='discussion of obtaining a Moroccan visa for unnamed woman', is_interesting=True),
    EmailCfg(id='031152', description='discussion of notoriously corrupt Kazakh politician Rakhat Aliyev', is_interesting=True),
    EmailCfg(id='032671', description='connections to Fusion GPS who produced the Steele Dossier on Trump'),
    EmailCfg(id='033052', description='connections to Fusion GPS who produced the Steele Dossier on Trump'),
    EmailCfg(id='031472', description="discussion of publishing an audio recording related to the coup in Turkey"),
    EmailCfg(id='031830', description='Epstein gets defensive about the portayal of the 2008 financial crisis in the movie "Inside Job"', truncate_to=400),
    EmailCfg(id='031333', description='Fort Knox conspiracy theory, looks like Russian disinfo', is_fwded_article=True),
    EmailCfg(id='031335', description='Fort Knox conspiracy theory, looks like Russian disinfo', is_fwded_article=True),
    EmailCfg(id='030648', description=IS_IT_ROGER_STONE),
    EmailCfg(id='030762', description=IS_IT_ROGER_STONE),
    EmailCfg(id='030649', description=IS_IT_ROGER_STONE),
    EmailCfg(id='026026', description=IS_IT_ROGER_STONE),
    EmailCfg(id='026030', description=IS_IT_ROGER_STONE),
    EmailCfg(id='026033', description=IS_IT_ROGER_STONE),
    EmailCfg(id='031011', description='jokes about Chicago corruption', duplicate_ids=['031090'], truncate_to=SHORT_TRUNCATE_TO),
    EmailCfg(id='030745', description="planning a public statement for Ghislaine", truncate_to=NO_TRUNCATE),
    EmailCfg(id='031320', description=f'routing Gratitude foundation money through {PEGGY_SIEGAL}', is_interesting=True),
    EmailCfg(id='016693', description='signed "MM"'),
    EmailCfg(id='023627', description=WOLFF_EPSTEIN_ARTICLE_DRAFT, is_fwded_article=True, is_interesting=True, truncate_to=16800),
    EmailCfg(id='028524', description='Zach Braff op-ed on Woody Allen in NYT', is_fwded_article=True, is_interesting=False),
    EmailCfg(id='031206', duplicate_ids=['031227']),
    EmailCfg(id='031591', duplicate_ids=['031442', '031996']),
    EmailCfg(id='031301', duplicate_ids=['022202', '029975']),
    EmailCfg(id='031428', duplicate_ids=['031388'], is_fwded_article=True),
    EmailCfg(id='033528', duplicate_ids=['033517'], is_fwded_article=True),
    EmailCfg(id='030238', duplicate_ids=['031130'], is_fwded_article=True),
    EmailCfg(id='031112', duplicate_ids=['030876'], is_fwded_article=True),
    EmailCfg(id='031423', duplicate_ids=['025361'], is_fwded_article=True),
    EmailCfg(id='026298', duplicate_ids=['026499'], is_fwded_article=True, comment='Written by someone else?'),
    EmailCfg(id='029692', duplicate_ids=['029779'], is_fwded_article=True, comment='WaPo article'),
    EmailCfg(id='022344', duplicate_ids=['028529'], is_fwded_article=True, comment='Bill Gates is most admired from Nikolic'),
    EmailCfg(id='018197', duplicate_ids=['028648'], is_fwded_article=True, comment='Ray Takeyh article fwd'),
    EmailCfg(id='028728', duplicate_ids=['027102'], is_fwded_article=True, comment='WSJ forward to Larry Summers'),
    EmailCfg(id='028781', duplicate_ids=['013460'], is_fwded_article=True, comment="Atlantic on Jim Yong Kim, Obama's World Bank Pick"),
    EmailCfg(id='025041', duplicate_ids=['028675'], is_fwded_article=True, comment='Obama agenda'),
    EmailCfg(id='031136', duplicate_ids=['028791'], is_fwded_article=True, comment="'Smart Money is Fleeing US Stocks'"),
    EmailCfg(id='031779', duplicate_ids=['026938'], is_fwded_article=True, comment='Sarah Silverman on AI'),
    EmailCfg(id='029849', duplicate_ids=['033482'], is_fwded_article=True, comment='Fareed Zakaria: Trump sells America short),'),
    EmailCfg(id='032023', duplicate_ids=['032012'], is_fwded_article=True, comment='American-Israeli Cooperative Enterprise Newsletter'),
    EmailCfg(id='021758', duplicate_ids=['030616'], is_fwded_article=True, comment="Radar Online article about Epstein's early prison release"),
    EmailCfg(id='033297', duplicate_ids=['033586'], is_fwded_article=True, comment='Sultan Sulayem article about Trump and Russia'),
    EmailCfg(id='021231', is_fwded_article=True, comment='11 places with worse economy than US'),
    EmailCfg(id='021729', is_fwded_article=True, comment='Acosta rebuke'),
    EmailCfg(id='025643', is_fwded_article=True, comment='Alice Fisher stated to be in the mix of potential candidates for new FBI director.'),
    EmailCfg(id='029905', is_fwded_article=True, comment='Ann Coulter'),
    EmailCfg(id='031340', is_fwded_article=True, comment='article about Alex Jones threatening Robert Mueller'),
    EmailCfg(id='029021', is_fwded_article=True, comment='article about bannon sent by Alain Forget'),
    EmailCfg(id='026605', is_fwded_article=True, comment='article about Ruemmler turning down attorney general job by NEDRA PICKLER'),
    EmailCfg(id='031569', is_fwded_article=True, comment='article by Kathryn Alexeeff fwded to Peter Thiel'),
    EmailCfg(id='013405', is_fwded_article=True, comment='articles about epstein case'),
    EmailCfg(id='016218', is_fwded_article=True, comment='AT&T confirms it paid Trump lawyer Cohen for insights on Trump'),
    EmailCfg(id='030209', is_fwded_article=True, comment='Atlantic Council "Syria: Blackberry Diplomacy"'),
    EmailCfg(id='030372', is_fwded_article=True, comment='Bannon China Iran'),
    EmailCfg(id='023564', is_fwded_article=True, comment="Bloomberg: Leon Black's Tax-Overhaul Dilemma Could Alter Wall Street Model"),
    EmailCfg(id='024300', is_fwded_article=True, comment='Bookstore owner calls police after customer confronted Steve Bannon'),
    EmailCfg(id='016801', is_fwded_article=True, comment='Capital Market Outlook'),
    EmailCfg(id='033329', is_fwded_article=True, comment='Chinese economists'),
    EmailCfg(id='029625', is_fwded_article=True, comment='Conchita Sarnoff Daily Beast Articles - Epstein Sex Trafficking Investigation and Settlement'),
    EmailCfg(id='030519', is_fwded_article=True, comment='Daily Mail on Prince Andrew'),
    EmailCfg(id='029509', is_fwded_article=True, comment='Deepak Chopra LSD, Quantum Healing'),
    EmailCfg(id='033301', is_fwded_article=True, comment='description of Trump jet'),
    EmailCfg(id='030865', is_fwded_article=True, comment='Deutsche bank research'),
    EmailCfg(id='022624', is_fwded_article=True, comment='Disgusting: Clinton Snared In Pedophile Ring'),
    EmailCfg(id='030927', is_fwded_article=True, comment="don't talk to the FBI"),
    EmailCfg(id='022673', is_fwded_article=True, comment='Epstein + Clinton'),
    EmailCfg(id='014523', is_fwded_article=True, comment='finance research'),
    EmailCfg(id='014857', is_fwded_article=True, comment='finance research'),
    EmailCfg(id='029458', is_fwded_article=True, comment='finance research'),
    EmailCfg(id='026893', is_fwded_article=True, comment='finance research'),
    EmailCfg(id='033362', is_fwded_article=True, comment='finance research'),
    EmailCfg(id='029505', is_fwded_article=True, comment='Foreign Policy Middle Eastern Monarchs Look at the Trump'),
    EmailCfg(id='030868', is_fwded_article=True, comment="'He doesn't like this sh*t': Trump reportedly hates his job and his staff after 1 month"),
    EmailCfg(id='021764', is_fwded_article=True, comment='He Was 50 and They Were Girls'),
    EmailCfg(id='024384', is_fwded_article=True, comment='interview with Bill Siegal re: Islam'),
    EmailCfg(id='031774', is_fwded_article=True, comment='Krassner fwd of Palmer Report article'),
    EmailCfg(id='033345', is_fwded_article=True, comment='Krassner fwd of Palmer Report article'),
    EmailCfg(id='029903', is_fwded_article=True, comment='Krassner fwd of Ann Coulter article about Epstein'),
    EmailCfg(id='030266', is_fwded_article=True, comment='Krassner fwd of article about Dershowitz'),
    EmailCfg(id='023635', is_fwded_article=True, comment='Landon Thomas finance related'),
    EmailCfg(id='026637', is_fwded_article=True, comment='Landon Thomas finance related'),
    EmailCfg(id='030200', is_fwded_article=True, comment='Lawfare indicting a president'),
    EmailCfg(id='023001', is_fwded_article=True, comment='Miami Herald article timeline of the sex abuse case'),
    EmailCfg(id='021740', is_fwded_article=True, comment='Miami Herald article about Epstein prosecutor'),
    EmailCfg(id='023126', is_fwded_article=True, comment='Miami Herald on Alex Acosta'),
    EmailCfg(id='031399', is_fwded_article=True, comment="Miami U.S. Attorney's Office recuses itself from Jeffrey Epstein case"),
    EmailCfg(id='028508', is_fwded_article=True, comment='nanosatellites article'),
    EmailCfg(id='025231', is_fwded_article=True, comment='Newsmax: Laffer, Laffer: Obama Must Use Reaganomics to Save Economy The only way President Barack Obama can solve'),
    EmailCfg(id='031990', is_fwded_article=True, comment='Newsmax on Ken Starr'),
    EmailCfg(id='026580', is_fwded_article=True, comment='NPR: Antigua: Land Of Sun, Sand, And Super Cheap'),
    EmailCfg(id='030326', is_fwded_article=True, comment='NYP Congressional candidate compares Melania Trump to prostitute'),
    EmailCfg(id='031988', is_fwded_article=True, comment='NYT review of Inside Job'),
    EmailCfg(id='028536', is_fwded_article=True, comment='Palm Beach Post FBI Epstein files say he gave info. Does it explain sweetheart deal?'),
    EmailCfg(id='030983', is_fwded_article=True, comment='Power Line blog Alex Acosta and Jeffrey Epstein Plea Deal Analysis'),
    EmailCfg(id='019845', is_fwded_article=True, comment='Pro Publica article on Preet Bharara'),
    EmailCfg(id='014525', is_fwded_article=True, comment='really more of a mailing list from Paul Morris?'),
    EmailCfg(id='029859', is_fwded_article=True, comment='Palm Beach Post: Epstein paid three women $5.5 million to end lawsuits'),
    EmailCfg(id='030878', is_fwded_article=True, comment="Steve Bannon almost appeared in Michael Moore's 'Fahrenheit 11/9'"),
    EmailCfg(id='026551', is_fwded_article=True, comment='Sultan bin Sulayem "Ayatollah between the sheets"'),
    EmailCfg(id='031768', is_fwded_article=True, comment="Sultan bin Sulayem 'Horseface'"),
    EmailCfg(id='026829', is_fwded_article=True, comment='taxes'),
    EmailCfg(id='029901', is_fwded_article=True, comment='THE EDGE question'),
    EmailCfg(id='026924', is_fwded_article=True, comment='The Onion'),
    EmailCfg(id='031705', is_fwded_article=True, comment='Thomas Friedman why not in vegas?'),
    EmailCfg(id='029689', is_fwded_article=True, comment='Tunisia article to Larry Summers'),
    EmailCfg(id='030528', is_fwded_article=True, comment='Vicky Ward article'),
    EmailCfg(id='030460', is_fwded_article=True, comment='Vicky Ward article'),
    EmailCfg(id='020443', is_fwded_article=True, comment='WSJ Deplorables Bannon'),
    EmailCfg(id='026755', is_fwded_article=True, truncate_to=SHORT_TRUNCATE_TO, comment='Epstein self fwd', is_interesting=False),
    EmailCfg(id='026778', is_fwded_article=True, truncate_to=SHORT_TRUNCATE_TO, comment='Kahn taxes'),
    EmailCfg(id='033311', is_fwded_article=True, truncate_to=SHORT_TRUNCATE_TO, comment='Kahn taxes'),
    EmailCfg(id='029433', is_fwded_article=True, truncate_to=SHORT_TRUNCATE_TO, comment='Kahn taxes'),
    EmailCfg(id='031764', is_fwded_article=True, truncate_to=3500, comment='broidy malaysia'),
    EmailCfg(id='026273', is_fwded_article=True),
    EmailCfg(id='032475', date='2017-02-15 13:31:25'),
    EmailCfg(id='030373', date='2018-10-03 01:49:27'),
    EmailCfg(id='026631', duplicate_ids=['026632'], dupe_type='quoted'),
    EmailCfg(id='028768', duplicate_ids=['026563'], dupe_type='redacted'),
    EmailCfg(id='027056', duplicate_ids=['028762'], dupe_type='redacted'),
    EmailCfg(id='032248', duplicate_ids=['032246'], dupe_type='redacted'),
    EmailCfg(id='030628', duplicate_ids=['023065'], dupe_type='redacted'),
    EmailCfg(id='017523', duplicate_ids=['031226'], dupe_type='redacted'),
    EmailCfg(id='031099', duplicate_ids=['031008'], dupe_type='redacted'),
    EmailCfg(id='033596', duplicate_ids=['033463'], dupe_type='redacted'),
    EmailCfg(id='030624', duplicate_ids=['023018'], dupe_type='redacted'),
    EmailCfg(id='030335', duplicate_ids=['030596'], dupe_type='redacted'),
    EmailCfg(id='029841', duplicate_ids=['012711'], dupe_type='redacted'),
    EmailCfg(id='030414', duplicate_ids=['030578'], dupe_type='redacted'),
    EmailCfg(id='031135', duplicate_ids=['030634'], dupe_type='redacted'),
    EmailCfg(id='030620', duplicate_ids=['023067']),
    EmailCfg(id='029835', duplicate_ids=['028968']),
    EmailCfg(id='033512', duplicate_ids=['033361']),
    EmailCfg(id='030299', duplicate_ids=['021794']),
    EmailCfg(id='033575', duplicate_ids=['012898']),
    EmailCfg(id='031980', duplicate_ids=['019409']),
    EmailCfg(id='033486', duplicate_ids=['033156']),
    EmailCfg(id='025790', duplicate_ids=['031994']),
    EmailCfg(id='028497', duplicate_ids=['026228']),
    EmailCfg(id='019412', duplicate_ids=['028621']),
    EmailCfg(id='027053', duplicate_ids=['028765']),
    EmailCfg(id='027049', duplicate_ids=['028773']),
    EmailCfg(id='033580', duplicate_ids=['033207']),
    EmailCfg(id='028506', duplicate_ids=['025547']),
    EmailCfg(id='023024', duplicate_ids=['030622']),
    EmailCfg(id='030618', duplicate_ids=['023026']),
    EmailCfg(id='028780', duplicate_ids=['026834']),
    EmailCfg(id='028775', duplicate_ids=['026835']),
    EmailCfg(id='033251', duplicate_ids=['033489']),
    EmailCfg(id='031118', duplicate_ids=['019465']),
    EmailCfg(id='031912', duplicate_ids=['032158']),
    EmailCfg(id='030587', duplicate_ids=['030514']),
    EmailCfg(id='031089', duplicate_ids=['018084']),
    EmailCfg(id='031088', duplicate_ids=['030885']),
    EmailCfg(id='030859', duplicate_ids=['031067']),
    EmailCfg(id='030635', duplicate_ids=['031134']),
    EmailCfg(id='030311', duplicate_ids=['021790']),
    EmailCfg(id='033508', duplicate_ids=['029880']),
    EmailCfg(id='030493', duplicate_ids=['030612']),
    EmailCfg(id='032051', duplicate_ids=['031771']),
    EmailCfg(id='031346', duplicate_ids=['031426']),
    EmailCfg(id='031345', duplicate_ids=['031427']),
    EmailCfg(id='031343', duplicate_ids=['031432']),
    EmailCfg(id='031020', duplicate_ids=['031084']),
    EmailCfg(id='033354', duplicate_ids=['033485']),
    EmailCfg(id='031999', duplicate_ids=['021241']),
    EmailCfg(id='030502', duplicate_ids=['030602']),
    EmailCfg(id='030574', duplicate_ids=['030617']),
    EmailCfg(id='031156', duplicate_ids=['025226']),
    EmailCfg(id='031018', duplicate_ids=['031086']),
    EmailCfg(id='031026', duplicate_ids=['031079']),
    EmailCfg(id='032011', duplicate_ids=['031787']),
    EmailCfg(id='030606', duplicate_ids=['030498']),
    EmailCfg(id='032005', duplicate_ids=['021235']),
    EmailCfg(id='028505', duplicate_ids=['026160']),
    EmailCfg(id='031126', duplicate_ids=['030837']),
    EmailCfg(id='029624', duplicate_ids=['029778']),
    EmailCfg(id='031338', duplicate_ids=['031422']),
    EmailCfg(id='033587', duplicate_ids=['033289']),
    EmailCfg(id='032107', duplicate_ids=['012722']),
    EmailCfg(id='030844', duplicate_ids=['031114']),
    EmailCfg(id='031031', duplicate_ids=['031074']),
    EmailCfg(id='027032', duplicate_ids=['028531']),
    EmailCfg(id='026777', duplicate_ids=['028493']),
    EmailCfg(id='029837', duplicate_ids=['029255']),
    EmailCfg(id='029299', duplicate_ids=['033594'], is_interesting=True, comment='trump rec letter for boccio'),
    EmailCfg(id='030904', duplicate_ids=['031069']),
    EmailCfg(id='030006', duplicate_ids=['031165']),
    EmailCfg(id='025215', duplicate_ids=['031159']),
    EmailCfg(id='032068', duplicate_ids=['018158']),
    EmailCfg(id='031213', duplicate_ids=['031221']),
    EmailCfg(id='016595', duplicate_ids=['016690']),
    EmailCfg(id='029833', duplicate_ids=['028970']),
    EmailCfg(id='029839', duplicate_ids=['028958']),
    EmailCfg(id='029893', duplicate_ids=['033503']),
    EmailCfg(id='025878', duplicate_ids=['028486']),
    EmailCfg(id='032764', duplicate_ids=['033565']),
    EmailCfg(id='026618', duplicate_ids=['028485']),
    EmailCfg(id='029831', duplicate_ids=['028972']),
    EmailCfg(id='033498', duplicate_ids=['029884']),
    EmailCfg(id='028620', duplicate_ids=['027094']),
    EmailCfg(id='032456', duplicate_ids=['033579']),
    EmailCfg(id='030315', duplicate_ids=['030255']),
    EmailCfg(id='030614', duplicate_ids=['030491']),
    EmailCfg(id='033585', duplicate_ids=['032279']),
    EmailCfg(id='031220', duplicate_ids=['031189']),
    EmailCfg(id='032779', duplicate_ids=['033563']),
    EmailCfg(id='033230', duplicate_ids=['033576', '033577']),
    EmailCfg(id='032125', duplicate_ids=['023971']),
    EmailCfg(id='031230', duplicate_ids=['031203']),
    EmailCfg(id='031773', duplicate_ids=['032050']),
    EmailCfg(id='021400', duplicate_ids=['031983']),
    EmailCfg(id='029752', duplicate_ids=['023550']),
    EmailCfg(id='030339', duplicate_ids=['030592']),
    EmailCfg(id='032250', duplicate_ids=['033589'], truncate_to=1000, comment='Wolff article'),
    EmailCfg(id='028752', duplicate_ids=['026569'], subject='Re: Program & Attendee list'),
    EmailCfg(id='026548', duplicate_ids=['033491', '033495'], comment='033495 is HTML garbage version'),
    EmailCfg(id='013415', fwded_text_after='Darren K. Indyke'),
    EmailCfg(id='024624', fwded_text_after='On Tue, May 14'),
    EmailCfg(id='025888', fwded_text_after='Jul 24, 2015', comment='sultan asking about cholesterol drug'),
    EmailCfg(id='026362', fwded_text_after='Jul 24, 2015', comment='sultan asking about cholesterol drug'),
    EmailCfg(id='016413', fwded_text_after='In a former warehouse'),
    EmailCfg(id='025548', fwded_text_after='Edward Jay Epstein'),
    EmailCfg(id='032806', fwded_text_after='• Sep 13, 2018'),
    EmailCfg(id='028943', fwded_text_after='-Lisa'),
    EmailCfg(id='029431', fwded_text_after='I am writing now'),
    EmailCfg(id='020437', fwded_text_after='Will Cohen Cooperate'),
    EmailCfg(id='026663', fwded_text_after='REGULATORY & COMPLIANCE ALERT'),
    EmailCfg(id='028921', fwded_text_after='Salacious new chapter'),
    EmailCfg(id='030324', fwded_text_after='For Federal Programs'),
    EmailCfg(id='022766', fwded_text_after='--- On Wed, 4/22/15'),
    EmailCfg(id='025606', fwded_text_after='> On May 6,'),
    EmailCfg(id='024251', fwded_text_after='Debate Schedule', truncate_to=SHORT_TRUNCATE_TO, comment='Kahn taxes'),
    EmailCfg(id='022977', fwded_text_after='Top of Form', truncate_to=1800, comment='Krassner with huge attachments field'),
    EmailCfg(id='033420', fwded_text_after='Slowing economy could increase pressure on'),
    EmailCfg(id='019203', fwded_text_after='This end-of-the-year'),
    EmailCfg(id='022207', fwded_text_after='Web Images Videos Maps'),
    EmailCfg(id='033210', fwded_text_after='Trump appears with mobster-affiliated'),
    EmailCfg(id='030989', fwded_text_after='New book paints sordid picture of Trump real estate'),
    EmailCfg(id='029174', fwded_text_after='The US trade war against China'),
    EmailCfg(id='030015', fwded_text_after='Bill Clinton reportedly'),
    EmailCfg(id='026312', fwded_text_after='Steve Bannon trying to get on disgraced'),
    EmailCfg(id='031742', fwded_text_after="Trump's former campaign manager Paul Manafort"),
    EmailCfg(id='028925', description=f'{JOI_ITO} plays down Epstein\'s "bad press"', truncate_to=NO_TRUNCATE),
    EmailCfg(id='029773', fwded_text_after='Omar Quadhafi', duplicate_ids=['012685']),
    EmailCfg(id='012197_4', fwded_text_after='Thanks -- Jay', is_fwded_article=False),
    EmailCfg(
        id='030727',
        description='Epstein requesting help for Russia, discussion of unknown dead Chinese shareholder',
        is_interesting=True,
        truncate_to=400,
    ),
    EmailCfg(
        id='025879',
        description="internal email from Epstein's island manager to Epstein's lawyer saying Bill Clinton was never on the island",
        is_interesting=True
    ),
    EmailCfg(id='026449', description="comments about Trump's 'former bridge girl and toy'", is_interesting=True),
    EmailCfg(id='032842', description='discussion of "stealing" a casino in Atlantic City', is_interesting=True),
    EmailCfg(id='033377', description="Epstein says he knows Russian oligarch Oleg Deripaska", is_interesting=True),
    EmailCfg(id='023454', description='Email invitation sent to tech CEOs and Epstein', is_interesting=True, truncate_to=1878),
    EmailCfg(
        id='030950',
        description=f"{IAN_OSBORNE} spending quality time in Russia before Jawbone investment",
        highlight_quote='fatty at LinkedIn',
        truncate_to=4500,
    ),
    EmailCfg(id='029098', description=f"{MASHA_DROKOVA}'s skype contact is in Moscow", is_interesting=True),
    EmailCfg(id='032229', description=f'{MICHAEL_WOLFF} offers ideas for entrapping Trump', is_interesting=True),
    EmailCfg(id='020143', description=f"{STEVEN_SINOFSKY} has heard a sad story about women in tech from {MASHA_DROKOVA}", truncate_to=1000),
    EmailCfg(
        id='030295',
        description=f"TerraMar Project was {GHISLAINE_MAXWELL} healthy oceans related attempt at reputation rehabilitation",
        truncate_to=4200,
    ),
    EmailCfg(id='028784', is_interesting=True, duplicate_ids=['026549'], comment='seminars: Money / Power'),
    EmailCfg(id='030714', is_interesting=True, description='Bannon gets a shout out from Russian nationalist Alexander Dugan'),
    EmailCfg(id='025233', is_interesting=True, description='Reputation.com discussion'),
    EmailCfg(id='017827', is_interesting=True, description='Bannon / Peggy Siegal email about netflix doc on Epstein'),
    EmailCfg(id='030725', is_interesting=True, comment='David Stern in Moscow'),
    EmailCfg(id='030245', is_interesting=True, comment='Epstein rationalizes his behavior in an open letter to the world'),
    EmailCfg(id='032906', is_interesting=True, comment='David Blaine email'),
    EmailCfg(id='029609', is_interesting=True, comment='Joi Ito'),
    EmailCfg(id='030222', is_interesting=True, comment='Ross Gow / Ghislaine correspondence'),
    EmailCfg(id='029545', is_interesting=True, comment='Tyler Shears reputation'),
    EmailCfg(id='025812', is_interesting=True, comment='Tyler Shears reputation'),
    EmailCfg(id='026028', is_interesting=True, description=f"Epstein introduces {LARRY_SUMMERS} to {ALLEGED_KARIM_WADE}"),
    EmailCfg(
        id='029914',
        description='Epstein and Lord Mandelson discuss Russian investments',
        is_interesting=True,
        truncate_to=4500,
    ),
    EmailCfg(id='033453', is_interesting=True, description='possibly an email from one of the women who sued Trump?'),
    EmailCfg(id='026036', is_interesting=True, truncate_to=6000, comment='Gino Yu blockchain mention'),
    EmailCfg(id='030467', duplicate_ids=['030584']),
    EmailCfg(id='019321', truncate_to=700),
    EmailCfg(
        id='013484',
        description='Peter Thiel conference speaker list',
        non_participants=[ARIANE_DE_ROTHSCHILD, BRAD_WECHSLER, DAVID_SCHOEN, 'Mozilla'],
        truncate_to=700,
    ),
    EmailCfg(id='025594', truncate_to=720),
    EmailCfg(id='022247', truncate_to=2000),
    EmailCfg(id='025655', truncate_to=400, comment='reply to article'),
    EmailCfg(id='029684', truncate_to=402, comment='Maldives reply'),
    EmailCfg(id='032865', truncate_to=445, comment='Barton reply'),
    EmailCfg(id='029100', truncate_to=450, comment='drokova'),
    EmailCfg(id='023717', truncate_to=489, comment='reply to article'),
    EmailCfg(id='026451', truncate_to=500, comment='reply to article'),
    EmailCfg(id='031619', truncate_to=652, comment='Reply to grab em by the pussy story'),
    EmailCfg(id='021096', truncate_to=700, comment='Sinofsky article quote'),
    EmailCfg(id='029680', truncate_to=900, comment='Maldives'),
    EmailCfg(id='029534', truncate_to=900, comment='Maldives'),
    EmailCfg(id='028760', truncate_to=900, comment='Epstein in an argument with someone'),
    EmailCfg(id='028757', truncate_to=900, comment='Epstein in an argument with someone'),
    EmailCfg(id='027126', truncate_to=1000, comment='Summers'),
    EmailCfg(id='027028', truncate_to=1000, comment='Tom Pritzer penny pritzker'),
    EmailCfg(id='030589', truncate_to=1000, comment='Brett Jaffe Fwd'),
    EmailCfg(id='031217', truncate_to=1800, duplicate_ids=['021761'], comment='1st email for dersh, has long article'),
    EmailCfg(id='029342', truncate_to=2000, comment='Hakeem Jeffries fundraiser'),
    EmailCfg(id='026059', truncate_to=2650, comment='Rothschild'),
    EmailCfg(id='017574', truncate_to=4000, comment=f'{LISA_RANDALL} invite'),
    EmailCfg(id='018045', truncate_to=SHORT_TRUNCATE_TO, comment='invite'),
    EmailCfg(id='028494', truncate_to=NO_TRUNCATE, duplicate_ids=['026234'], comment='in palm beach w/trump people'),
    EmailCfg(id='032643', truncate_to=NO_TRUNCATE, comment='Anas al Rasheed'),
    EmailCfg(id='027059', truncate_to=NO_TRUNCATE, comment='Jean Luc Brunel and Boris Nikolic'),
    EmailCfg(id='028589', truncate_to=NO_TRUNCATE, comment='Long thread with Reid Weingarten'),
    EmailCfg(id='029910', truncate_to=NO_TRUNCATE, comment='Tom Pritzer Aspen'),
    EmailCfg(id='025163', truncate_to=NO_TRUNCATE, comment='Tom Pritzer'),
    EmailCfg(id='022265', truncate_to=NO_TRUNCATE),
    EmailCfg(id='026243', truncate_to=NO_TRUNCATE),
    EmailCfg(id='014797_1', has_uninteresting_bccs=True),
    binant_redacted('032964'),
    binant_redacted('032968'),
    binant_redacted('032467'),
    binant_redacted('032480'),
    binant_redacted('032486'),
    binant_redacted('032491'),
    binant_redacted('032975'),
    binant_redacted('032496'),
    binant_redacted('032464', NO_TRUNCATE),

    # Authors DOJ files
    EmailCfg(id='EFTA00645449', author=ANASTASIYA_SIROOCHENKO, author_reason='Jmail'),
    EmailCfg(id='EFTA00040142', author=ATT_COURT_APPEARANCE_TEAM, recipients=[USANYS]),
    EmailCfg(id='EFTA01040692', author=ALAN_DLUGASH, description='meeting about tax implications of ZCash'),
    EmailCfg(id='EFTA01777318', author=BEN_GOERTZEL),
    EmailCfg(id='EFTA01946710', author=BEN_GOERTZEL),
    EmailCfg(id='EFTA02679857', author=BEN_GOERTZEL),
    EmailCfg(id='EFTA00771142', author=BEN_GOERTZEL),
    EmailCfg(id='EFTA00773916', author=BEN_GOERTZEL),
    EmailCfg(id='EFTA02437992', author=BEN_GOERTZEL, recipients=[None, JEFFREY_EPSTEIN]),
    EmailCfg(id='EFTA00039357', author=BUREAU_OF_PRISONS, recipients=['DOJ Inspector General']),
    EmailCfg(id='EFTA01851487', author=CHRISTINA_GALBRAITH, author_reason='topic, cell: in redacted sig'),
    EmailCfg(id='EFTA01851738', author=CHRISTINA_GALBRAITH, author_reason='topic, cell: in redacted sig'),
    EmailCfg(id='EFTA01947908', author=CHRISTINA_GALBRAITH, author_reason='"Christina" appears in EFTA01950559'),
    EmailCfg(id='EFTA01940349', author=CHRISTINA_GALBRAITH, author_uncertain='subject matter'),
    EmailCfg(id='EFTA01747822', author=DARREN_INDYKE, author_reason='reply'),
    EmailCfg(id='EFTA00039967', author='DOJ London', recipients=[USANYS]),
    EmailCfg(
        id='EFTA00039660',
        author='DOJ Chief Psychologist',
        description="report on Epstein's psychological state in jail",
        is_interesting=True,
        recipients=[USANYS],
    ),
    EmailCfg(id='EFTA01776893', author=DONALD_NORMAN, author_reason='"This is Donald"', duplicate_ids=['EFTA00915423']),
    EmailCfg(id='EFTA00656005', author=DONALD_NORMAN, author_reason='signed "Donald"', duplicate_ids=['EFTA02691296', 'EFTA01862178']),
    EmailCfg(id='EFTA02660820', author=FAWZI_SIAM, truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02349713', author=FAWZI_SIAM, truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02661442', author=FAWZI_SIAM, truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA00039985', author='Florence Hutner', recipients=[USANYS], author_reason='signature'),
    EmailCfg(
        id='EFTA00677752',
        author=GANBAT_CHULUUNKHUU,
        description=f'discussion of getting a job in sustainable energy in Mongolia for {REDACTED} ({RENATA_BOLOTOVA}?)'
    ),
    EmailCfg(id='EFTA02069096', author=GANBAT_CHULUUNKHUU),
    EmailCfg(id='EFTA02645857', author=GANBAT_CHULUUNKHUU),
    EmailCfg(id='EFTA02406725', author=GANBAT_CHULUUNKHUU),
    EmailCfg(id='EFTA01030561', author=GANBAT_CHULUUNKHUU, author_reason='signature', is_fwded_article=True),
    EmailCfg(
        id='EFTA01041008',
        author=GANBAT_CHULUUNKHUU,
        description=f"Esptein wants \"a job re water /energy\" for someone ({RENATA_BOLOTOVA} {QUESTION_MARKS})",
    ),
    EmailCfg(id='EFTA02469895', author=GREG_WYLER, author_uncertain=True),
    EmailCfg(
        id='EFTA00845330',
        author=GREG_WYLER,
        author_reason='"Greg" + Wyler is on other emails with Stern and Epstein at that time',
    ),
    EmailCfg(id='EFTA02640711', author=HAMAD_BIN_JASSIM, description='Jabor Y / HBJ home address', is_interesting=True),
    EmailCfg(id='EFTA02334332', author=JASON_CALACANIS),
    EmailCfg(id='EFTA02434805', author=JEAN_LUC_BRUNEL, author_uncertain='reply', description='what lawyers offices got sealed?'),
    EmailCfg(
        id='EFTA00838218',
        author=JULIA_SANTOS,
        author_uncertain='https://x.com/FlippersUpNow/status/2021662725412110565',
        description='author apparently is daughter of an FSB officer',
    ),
    EmailCfg(id='EFTA02296929', author=KARYNA_SHULIAK, author_reason='Valentines Day congrats'),
    EmailCfg(id='EFTA00953261', author=LARRY_SUMMERS, recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(
        id='EFTA00357525',
        author=LESLEY_GROFF,
        author_uncertain=True,
        description=f'Nicole Junkermann / {VALAR_VENTURES} meeting',
        duplicate_ids=['EFTA02089447'],
        is_interesting=True,
        truncate_to=1_002,
    ),
    EmailCfg(
        id='EFTA00383023',
        author_reason='"Lesley" appears in body + Linda Stone signature',
        author=LESLEY_GROFF,
        description='heavily redacted',
        is_interesting=True,
        recipients=[LINDA_STONE],
    ),
    EmailCfg(
        id='EFTA02109391',
        author=LESLEY_GROFF,
        author_reason='"assistant to Jeffrey Epstein"',
        description=f"{AUSTIN_HILL} brought a woman named Ellaina Astra to Epstein's house",
        truncate_to=NO_TRUNCATE,
    ),
    EmailCfg(
        id='EFTA00675596',
        author=LESLEY_GROFF,
        author_uncertain='epstein scheduling',
        description=f"the president of Mongolia plans to vist Epstein",
        is_interesting=True
    ),
    EmailCfg(id='EFTA02065181', author=LESLEY_GROFF),
    EmailCfg(id='EFTA02062308', author=LESLEY_GROFF),
    EmailCfg(id='EFTA02246900', author=LESLEY_GROFF),
    EmailCfg(id='EFTA00461202', author=LESLEY_GROFF),
    EmailCfg(id='EFTA02246744', author=LESLEY_GROFF),
    EmailCfg(id='EFTA02102384', author=LESLEY_GROFF),
    EmailCfg(id='EFTA02067245', author=LESLEY_GROFF, description=VALAR_MEETING, is_interesting=True, author_uncertain=True, truncate_to=600),
    EmailCfg(id='EFTA02068490', author=LESLEY_GROFF, description=VALAR_MEETING, is_interesting=True, author_uncertain=True, truncate_to=540),
    EmailCfg(id='EFTA02067872', author=LESLEY_GROFF, description=VALAR_MEETING, author_uncertain=True),
    EmailCfg(id='EFTA01731288', author=LESLEY_GROFF, author_reason='signature'),
    # These attributions are based mostly on the email text being about Epstein scheduling
    EmailCfg(id='EFTA02089459', author=LESLEY_GROFF, author_uncertain=True, description='Nicole Junkermann meeting'),
    EmailCfg(id='EFTA00428084', author=LESLEY_GROFF, author_uncertain=True, recipients=[JEFFREY_EPSTEIN], recipient_uncertain='meeting'),
    EmailCfg(id='EFTA00334935', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02246686', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02220616', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02143419', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00384399', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02254640', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00552880', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00494858', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00357521', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02100999', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02090028', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00357488', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00642571', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00357379', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00357957', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02229858', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02174702', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02068381', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02067282', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02060931', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02092005', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02095399', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00361741', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00361736', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00371755', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA02092108', author=LESLEY_GROFF, author_uncertain=True),
    EmailCfg(id='EFTA00424931', author=LESLEY_GROFF, author_uncertain=True, duplicate_ids=['EFTA02181004']),
    EmailCfg(id='EFTA02005819', author=LESLEY_GROFF, author_uncertain=True, duplicate_ids=['EFTA01890165']),
    EmailCfg(id='EFTA00357509', author=LESLEY_GROFF, author_uncertain=True, duplicate_ids=['EFTA02089323']),
    EmailCfg(id='EFTA02225815', author=LESLEY_GROFF, author_uncertain=True, truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02225790', author=LESLEY_GROFF, author_uncertain=True, recipients=[MASHA_DROKOVA], truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA00697417', author=LESLEY_GROFF, author_uncertain=True, is_interesting=True, show_with_name=GANBAT_CHULUUNKHUU),
    EmailCfg(id='EFTA02104454', author=LESLEY_GROFF, author_uncertain='Epstein scheduling'),
    EmailCfg(id='EFTA02069175', author=LESLEY_GROFF, recipients=[GANBAT_CHULUUNKHUU], author_uncertain=True),
    EmailCfg(id='EFTA02271414', author=LESLEY_GROFF, recipients=[GANBAT_CHULUUNKHUU], author_uncertain=True),
    EmailCfg(id='EFTA00405795', author=LESLEY_GROFF, duplicate_ids=['EFTA02159829']),
    EmailCfg(id='EFTA00419742', author=LESLEY_GROFF, duplicate_ids=['EFTA02174857'], truncate_to=500),
    EmailCfg(
        id='EFTA00384774',
        author_reason='unique email signature',
        author=LINDA_STONE,
        description='visiting for the death of Red Burns',
        is_interesting=True,
        recipients=[LESLEY_GROFF],
    ),
    EmailCfg(
        id='EFTA02730473',
        author='Records Management (Sun Sentinel?)',
        is_interesting=False,
        recipients=['Records Management Division'],
    ),
    EmailCfg(
        id='EFTA00381451',
        author=LINDA_STONE,
        author_reason='"Typos, misspellings courtesy of iPhone."',
        recipients=[LESLEY_GROFF],
        truncate_to=800,
        recipient_uncertain='scheduling epstein',
    ),
    EmailCfg(id='EFTA02570478', author=LINDA_STONE, author_reason='signature'),
    EmailCfg(id='EFTA02584858', author=LINDA_STONE, author_reason='Tupos & Abbrvtns'),
    EmailCfg(id='EFTA01922840', author=LINDA_STONE, author_reason='Tupos & Abbrvtns'),
    EmailCfg(id='EFTA02394792', author=LINDA_STONE, author_reason=LINDA_STONE_ATTRIBUTION),
    EmailCfg(id='EFTA00706814', author=LINDA_STONE, author_reason=LINDA_STONE_ATTRIBUTION),
    EmailCfg(id='EFTA00703417', author=LINDA_STONE, author_reason=LINDA_STONE_ATTRIBUTION),
    EmailCfg(id='EFTA02354559', author=LINDA_STONE, author_reason=LINDA_STONE_ATTRIBUTION),
    EmailCfg(id='EFTA01802168', author=LINDA_STONE, author_uncertain='"Stone"'),
    EmailCfg(id='EFTA00701326', author=LINDA_STONE, author_uncertain='"Stone"'),
    EmailCfg(id='EFTA00397956', author=LINDA_STONE, author_reason='unique email signature'),
    EmailCfg(id='EFTA00770066', author=LISA_RANDALL, description=f"Epstein lists conferences he intends to fund", truncate_to=4500),
    EmailCfg(id='EFTA00920848', author=MARIA_PRUSAKOVA, author_uncertain='law school'),
    EmailCfg(id='EFTA02038002', author=MARIA_PRUSAKOVA, author_reason=CLIFFORD_CHANCE),
    EmailCfg(id='EFTA02036490', author=MARIA_PRUSAKOVA, author_reason=CLIFFORD_CHANCE),
    EmailCfg(id='EFTA02022813', author=MARIA_PRUSAKOVA, author_reason=CLIFFORD_CHANCE, highlight_quote='I want to learn more sexual tricks'),
    EmailCfg(id='EFTA02001536', author=MARIA_PRUSAKOVA, author_reason=CLIFFORD_CHANCE),
    EmailCfg(id='EFTA01772533', author=MARIA_PRUSAKOVA, author_reason=CLIFFORD_CHANCE),
    EmailCfg(id='EFTA01775280', author=MARIA_PRUSAKOVA, author_reason=CLIFFORD_CHANCE, truncate_to=2000),
    EmailCfg(id='EFTA02507271', author=MARIA_PRUSAKOVA, author_uncertain='LGT Bank in signature'),
    EmailCfg(id='EFTA00684871', author=MARIANA_IDZKOWSKA),
    EmailCfg(id='EFTA00674483', author=MARIANA_IDZKOWSKA),
    EmailCfg(id='EFTA00662373', author=MASHA_DROKOVA, author_reason='"Best, Masha"', highlight_quote='She is interesting. Great looks'),
    EmailCfg(id='EFTA00667366', author='Match.com', description=f"Match.com is redacted for some reason", truncate_to=300),
    EmailCfg(id='EFTA01986756', author=MELANIE_PHILLIPS, author_uncertain=f"{STEVEN_SINOFSKY}'s gf at the time"),
    EmailCfg(id='EFTA00355684', author='Mira Bach', is_interesting=False),
    EmailCfg(id='EFTA01063008', author=OLGA_PONOMAR_BECKER, author_reason='Jmail'),
    EmailCfg(id='EFTA02436834', author=PETER_MANDELSON, author_reason='reply'),
    EmailCfg(id='EFTA01834130', author=PETER_MANDELSON, author_reason='reply', is_interesting=False),
    EmailCfg(
        id='EFTA01988194',
        author=RASSECK_BOURGI,
        description=f'{RASSECK_BOURGI} using his wife\'s email "because it is a private email" to ask for favours re: Harvard',
        truncate_to=NO_TRUNCATE,
    ),
    EmailCfg(id='EFTA01978227', description=f"Epstein arranging tour of Harvard for {RASSECK_BOURGI}'s daughter"),
    EmailCfg(
        id='EFTA00773139',
        author=REINALDO_AVILA_DA_SILVA,
        description="Epstein calls Swedish billionaire Johan Eliasch \"not the brightest bulb\"",
        truncate_to=1000
    ),
    EmailCfg(
        id='EFTA02312343',
        description=f"email about sham marriage visa issues, possibly from {RENATA_BOLOTOVA}'s spouse",
        is_interesting=True,
    ),
    DocCfg(id='EFTA02312343_1', attached_to_email_id='EFTA02312343', description='translation of visa email', show_full_panel=True),
    EmailCfg(
        id='EFTA00708783',
        author=RENATA_BOLOTOVA,
        author_uncertain=SNEAKY_DOG,
        duplicate_ids=['EFTA02696436', 'EFTA02550142', 'EFTA02397691', 'EFTA01840867'],
    ),
    EmailCfg(
        id='EFTA02018237',
        author=RENATA_BOLOTOVA,
        duplicate_ids=['EFTA00930786', 'EFTA01770897'],
        author_uncertain=SNEAKY_DOG,
    ),
    EmailCfg(
        id='EFTA02561760',
        author=RENATA_BOLOTOVA,
        author_reason=SINCERELY_SNEAKY,
        duplicate_ids=['EFTA00945344', 'EFTA02563292', 'EFTA00948275'],
    ),
    EmailCfg(
        id='EFTA02538649',
        author=RENATA_BOLOTOVA,
        author_reason=f'{SNEAKY_DOG} + {TERJE_ROD_LARSEN} mention',
        description=f"email about a future job at {TERJE_ROD_LARSEN}'s International Peace Institute",
    ),
    EmailCfg(
        id='EFTA02540487',
        author_reason=f'{SNEAKY_DOG} + {TERJE_ROD_LARSEN} mention',
        author=RENATA_BOLOTOVA,
        description=f"email about a future job at {TERJE_ROD_LARSEN}'s International Peace Institute",
    ),
    EmailCfg(
        id='EFTA00912012',
        author_reason='renbolotova in body',
        author=RENATA_BOLOTOVA,
        description='this file has been removed from the DOJ site',
    ),
    EmailCfg(id='EFTA02025944', author=RENATA_BOLOTOVA, recipients=[JEFFREY_EPSTEIN], date='2012-01-23 06:00:00'),
    EmailCfg(id='EFTA01985762', author=RENATA_BOLOTOVA, recipients=[JEFFREY_EPSTEIN], date='2012-01-24 09:35:00'),
    EmailCfg(id='EFTA00711422', author=RENATA_BOLOTOVA, author_reason="Bolotova went on to work on water projects at IPI", author_uncertain=True),
    EmailCfg(id='EFTA00920177', author=RENATA_BOLOTOVA, author_reason='discussion of employment at Institute', truncate_to=350),
    EmailCfg(id='EFTA00920010', author=RENATA_BOLOTOVA, author_reason='renbolotova@gmail in body', description=f"{RENATA_BOLOTOVA} gets a job"),
    EmailCfg(id='EFTA02455567', author=RENATA_BOLOTOVA, author_reason='"sneaky"', description='completely redacted email body'),
    EmailCfg(id='EFTA01773417', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY, duplicate_ids=['EFTA01987876']),
    EmailCfg(id='EFTA00935516', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA02545360', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA02547825', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA02387781', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA02696764', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA02372848', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY, description=f"job in Puerto Rico"),
    EmailCfg(id='EFTA02376299', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA02389443', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA00703980', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA00699453', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA02404938', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA00671467', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY),
    EmailCfg(id='EFTA02719248', author=RENATA_BOLOTOVA, author_reason=SINCERELY_SNEAKY, duplicate_ids=['EFTA01803593']),
    EmailCfg(
        id='EFTA00639014',
        author=RENATA_BOLOTOVA,
        author_reason=SINCERELY_SNEAKY,
        duplicate_ids=['EFTA02347987'],
        highlight_quote='she said she is coming to the island soon',
    ),
    EmailCfg(id='EFTA00995559', author=RENATA_BOLOTOVA, author_reason='poorly redacted signature'),
    EmailCfg(id='EFTA01059181', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA01923844', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA00686861', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG, is_interesting=False),
    EmailCfg(id='EFTA00870433', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG, duplicate_ids=['EFTA01925240']),
    EmailCfg(id='EFTA01035614', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA01748575', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA01903041', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA01954115', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA01987876', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA00667874', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA02611134', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA02603940', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA02396796', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA01801003', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA00816407', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG, is_interesting=False),
    EmailCfg(id='EFTA02395750', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA00667441', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG, description=f"{RENATA_BOLOTOVA}'s mom comes to USA"),
    EmailCfg(id='EFTA01931339', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA00659818', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA01757037', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG),
    EmailCfg(
        id='EFTA00697443',
        author=RENATA_BOLOTOVA,
        author_uncertain=SNEAKY_DOG,
        description=f'Mongolian election outcome bodes well for {RENATA_BOLOTOVA}',
        truncate_to=1800,
    ),
    EmailCfg(
        id='EFTA00676720',
        author=RENATA_BOLOTOVA,
        author_uncertain=SNEAKY_DOG,
        description=f"{RENATA_BOLOTOVA} seems acquainted with {JEAN_LUC_BRUNEL}",
        duplicate_ids=['EFTA01961947'],
    ),
    EmailCfg(id='EFTA01961947', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG, recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(id='EFTA00826575', author=RENATA_BOLOTOVA, author_uncertain=SNEAKY_DOG, duplicate_ids=['EFTA02462211']),
    EmailCfg(id='EFTA00039796', author=SDNY, recipients=[USANYS]),
    EmailCfg(id='EFTA01926669', author=SERGEY_BELYAKOV),
    EmailCfg(id='EFTA00858688', author=SERGEY_BELYAKOV, description=f"Epstein introduces {EHUD_BARAK} to {SERGEY_BELYAKOV}"),
    EmailCfg(id='EFTA00704085', author=SERGEY_BELYAKOV, author_reason='response to EFTA00835324'),
    EmailCfg(id='EFTA01767424', author=SHAHER_ABDULHAK_BESHER, author_reason='"sincerely shaher"'),
    EmailCfg(id='EFTA00039663', author=STACEY_RICHMAN, recipients=[USANYS], author_reason='unredacted in EFTA00039662'),
    EmailCfg(id='EFTA00721168', author=STEVEN_SINOFSKY, author_uncertain='Sinofsky in previous To: field'),
    EmailCfg(id='EFTA00664619', author=SUE, author_reason='"Dear Sue"'),
    EmailCfg(
        id='EFTA02731689',
        author=USANYS,
        date='2023-06-09 20:14:00',
        author_uncertain=True,
        recipients=[USANYS],
        truncate_to=SHORT_TRUNCATE_TO,
    ),
    EmailCfg(
        id='EFTA00277089',
        author=USANYS,
        recipients=[USANYS],
        description="tip for the FBI / DOJ that Swedish billionaire Johan Eliasch may be connected to Epstein's crimes",
        duplicate_ids=['EFTA00151184']
    ),
    EmailCfg(
        id='EFTA00157083',
        author=USANYS,
        highlight_quote='STXU has recovered a password "asdfasdfasdfasdf" (no quotes) for item NYCO24364',
        truncate_to=1400,
    ),
    EmailCfg(id='EFTA02731755', author=USANYS),
    EmailCfg(id='EFTA00039890', author=USANYS),
    EmailCfg(id='EFTA00039662', author=USANYS),
    EmailCfg(id='EFTA00040141', author=USANYS),
    EmailCfg(id='EFTA02731644', author=USANYS),
    EmailCfg(id='EFTA00040144', author=USANYS),
    EmailCfg(id='EFTA00039995', author=USANYS),
    EmailCfg(id='EFTA00039813', author=USANYS),
    EmailCfg(id='EFTA00039815', author=USANYS),
    EmailCfg(id='EFTA00039825', author=USANYS),
    EmailCfg(id='EFTA02731783', author=USANYS, date='2022-01-21 17:28:00'),
    EmailCfg(id='EFTA02731578', author=USANYS, date='2021-05-28 10:00:00'),
    EmailCfg(id='EFTA02730468', author=USANYS, recipients=[USANYS], date='2019-07-11T08:25:00', date_uncertain='just wrong'),
    EmailCfg(id='EFTA00039983', author=USANYS, author_uncertain=True),
    EmailCfg(id='EFTA00039886', author=USANYS, author_uncertain=True),
    EmailCfg(id='EFTA02731651', author=USANYS, author_uncertain=True),
    EmailCfg(id='EFTA02731775', author=USANYS, author_uncertain=True),
    EmailCfg(id='EFTA02731646', author=USANYS, author_uncertain=True),
    EmailCfg(id='EFTA02731640', author=USANYS, author_uncertain=True),
    EmailCfg(id='EFTA02731643', author=USANYS, author_uncertain=True),
    EmailCfg(id='EFTA02731501', author=USANYS, author_uncertain=True),
    EmailCfg(id='EFTA02731633', author=USANYS, author_uncertain=True),
    EmailCfg(id='EFTA01660679', author=USANYS, author_uncertain=True, recipients=[FBI], recipient_uncertain=True),
    EmailCfg(id='EFTA02731699', author=USANYS, author_uncertain=True, recipients=[FBI], date='2021-05-27 10:19:00'),
    EmailCfg(id='EFTA00040121', author=USANYS, recipients=[ATT_COURT_APPEARANCE_TEAM]),
    EmailCfg(id='EFTA02731630', author=USANYS, recipients=[FBI]),
    EmailCfg(
        id='EFTA02731737',
        author=USANYS,
        author_uncertain=True,
        date='2023-06-30T16:05:00',
        is_interesting=True,
        recipients=[FBI],
        truncate_to=5000,
    ),
    EmailCfg(
        id='EFTA00090614',
        author=USANYS,
        author_uncertain=True,
        description='alleges cover up of crimes of wealthy / powerful people by DA Cyrus Vance',
        recipients=[FBI],
        recipient_uncertain=True,
    ),
    EmailCfg(id='EFTA02731593', author=USANYS, recipients=['Manhattan DA']),
    EmailCfg(id='EFTA00039419', author=USANYS, recipients=['Manhattan DA']),
    EmailCfg(id='EFTA02731617', author=USANYS, recipients=[SDNY], date='2021-04-28T15:05:41'),
    EmailCfg(id='EFTA00151184', author=USANYS, recipients=[USANYS]),
    EmailCfg(id='EFTA02731615', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731684', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731485', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731736', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731478', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA00039872', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA00039868', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731490', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731477', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731660', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA00039820', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731638', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731636', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731637', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731659', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731781', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731774', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731724', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731771', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731486', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731604', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731618', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(
        id='EFTA02731655',
        author=USANYS,
        author_uncertain=True,
        description=f"specific allegations against {LEON_BLACK}",
        is_interesting=True,
        recipients=[USANYS],
    ),
    EmailCfg(id='EFTA02731608', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731612', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731729', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731484', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731757', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA02731623', author=USANYS, recipients=[USANYS], author_uncertain=True),
    EmailCfg(id='EFTA00039879', author=USANYS, recipients=[USANYS], recipient_uncertain=True),
    EmailCfg(
        id='EFTA02731488',
        author=USANYS,
        author_uncertain=True,
        description=f"possible evidence of girls being trafficked to {LEON_BLACK}",
        recipients=[USANYS],
        is_interesting=True,
    ),
    EmailCfg(id='EFTA02731733', author=USANYS, recipients=[USANYS], date='2021-05-17 17:29:00', author_uncertain=True),
    EmailCfg(id='EFTA02731754', author=USANYS, recipients=[USANYS], date='2024-03-06T23:24:00', author_uncertain=True),
    EmailCfg(id='EFTA02731732', author=USANYS, recipients=[USANYS], date='2024-03-06T12:21:00', author_uncertain=True),
    EmailCfg(id='EFTA02731528', author=USANYS, recipients=[USANYS], date='2021-05-06 09:39:15', author_uncertain=True),
    EmailCfg(id='EFTA02731475', author=USANYS, recipients=[USANYS], date='2023-05-31T20:53:00', author_uncertain=True),
    EmailCfg(id='EFTA02731697', author=USANYS, recipients=[USANYS], date='2021-06-07 17:33:00', author_uncertain=True),
    EmailCfg(id='EFTA02731583', author=USANYS, recipients=[USANYS], date='2022-01-21 17:28:00', author_uncertain=True),
    EmailCfg(id='EFTA02731587', author=USANYS, recipients=[USANYS], date='2022-01-21 17:28:00', author_uncertain=True),

    # Recipients
    EmailCfg(
        id='EFTA01043393',
        description=f'did Epstein and {BROCK_PIERCE} have a falling out?',
        is_interesting=True,
        recipients=[ANDREW_FARKAS],
    ),
    EmailCfg(id='EFTA02068282', recipients=[ANDREW_MCCORMACK]),
    EmailCfg(id='EFTA01913311', recipients=[CHRISTINA_GALBRAITH], duplicate_ids=['EFTA00994273']),
    EmailCfg(id='EFTA01950559', recipients=[CHRISTINA_GALBRAITH], recipient_uncertain='"Christina" in thread'),
    EmailCfg(id='EFTA01745739', recipients=[CHRISTINA_GALBRAITH, JEFFREY_EPSTEIN], author_reason='topic, cell: in redacted sig'),
    EmailCfg(id='EFTA02518357', recipients=[CHRISTINA_GALBRAITH, RICHARD_KAHN], author_reason='"Christina" appears in email'),
    EmailCfg(id='EFTA00915426', recipients=[DONALD_NORMAN], author_reason='"This is Donald"'),
    EmailCfg(id='EFTA00916133', recipients=[DONALD_NORMAN], author_reason='signed "Donald"', duplicate_ids=['EFTA01862243']),
    EmailCfg(id='EFTA02662381', recipients=[FAWZI_SIAM]),
    EmailCfg(id='EFTA01054971', recipients=[FAWZI_SIAM], truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02646138', recipients=[GANBAT_CHULUUNKHUU]),
    EmailCfg(id='EFTA01041151', recipients=[GANBAT_CHULUUNKHUU]),
    EmailCfg(id='EFTA01041159', recipients=[GANBAT_CHULUUNKHUU]),
    EmailCfg(id='EFTA01040918', recipients=[GANBAT_CHULUUNKHUU]),
    EmailCfg(id='EFTA00913164', recipients=[GAVIN_ANDRESEN]),
    EmailCfg(id='EFTA02624738', recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(id='EFTA02629770', recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(id='EFTA00705664', recipients=[JEFFREY_EPSTEIN]),
    EmailCfg(id='EFTA02160715', recipients=[JEFFREY_EPSTEIN], recipient_uncertain='looks like lesley'),
    EmailCfg(id='EFTA01763770', recipients=[JEFFREY_EPSTEIN, JEAN_LUC_BRUNEL]),
    EmailCfg(id='EFTA00716532', recipients=[JEFFREY_EPSTEIN], truncate_to=479),
    EmailCfg(id='EFTA02328335', recipients=[JEFFREY_EPSTEIN, KARYNA_SHULIAK, None]),
    EmailCfg(id='EFTA02622513', recipients=[JULIA_SANTOS], author_reason='https://x.com/FlippersUpNow/status/2021662725412110565'),
    EmailCfg(
        id='EFTA02256631',
        recipients=[LESLEY_GROFF],
        description=f"{MASHA_DROKOVA} introduces {DANIEL_SCHMACHTENBERGER}",
        truncate_to=NO_TRUNCATE,
    ),
    EmailCfg(id='EFTA02187050', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA00357515', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA00357508', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA00462608', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA00357523', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA02089992', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA01051609', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA02089433', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA02041142', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA02238824', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA02246341', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA02279390', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA00840591', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA00369335', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA02227488', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA02234448', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA00482121', recipients=[LESLEY_GROFF]),
    EmailCfg(id='EFTA00368951', recipients=[LESLEY_GROFF], author_reason='can be seen in EFTA00368958'),
    EmailCfg(id='EFTA00468081', recipients=[LESLEY_GROFF], recipient_uncertain=True),
    EmailCfg(id='EFTA02175423', recipients=[LESLEY_GROFF], truncate_to=650),
    EmailCfg(id='EFTA00313867', recipients=[LESLEY_GROFF], truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA00383027', recipients=[LINDA_STONE]),
    EmailCfg(id='EFTA01002282', recipients=[LINDA_STONE], author_reason='signature'),
    EmailCfg(id='EFTA02266524', recipients=[MARIA_PRUSAKOVA], author_reason=CRYPTO_PR_LAB, description='Medici Bank'),
    EmailCfg(id='EFTA02503155', recipients=[MARIA_PRUSAKOVA], author_reason='visible in quoted reply'),
    EmailCfg(
        id='EFTA00579769',
        recipients=['Melania'],
        date='2002-10-23 15:49:00',
        description="Melania... Trump?",
        is_interesting=True,
        truncate_to=587,
    ),
    EmailCfg(id='EFTA02731632', recipients=[OFFICE_OF_THE_DEPUTY_ATTORNEY_GENERAL]),
    EmailCfg(id='EFTA00681554', recipients=[OLGA_PONOMAR_BECKER]),
    EmailCfg(id='EFTA02669915', recipients=[OLGA_PONOMAR_BECKER]),
    EmailCfg(id='EFTA00745622', recipients=[PETER_MANDELSON], truncate_to=520),
    EmailCfg(
        id='EFTA00892654',
        description='("moneyland" is a term some jounalists use to describe offshore corrupt finance)',
        highlight_quote='i need your head in moneyland',
        recipients=[PETER_MANDELSON],
        recipient_uncertain=True,
        truncate_to=1_700,
    ),
    EmailCfg(
        id='EFTA00926593',
        author=PHILIP_ROSEDALE,
        description='discussion of a symposium on deception and alternative finance',
        is_interesting=True,
    ),
    EmailCfg(id='EFTA01039112', recipients=[RENATA_BOLOTOVA], recipient_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA01006355', recipients=[RENATA_BOLOTOVA], recipient_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA02547678', recipients=[RENATA_BOLOTOVA], recipient_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA02626300', recipients=[RENATA_BOLOTOVA], recipient_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA00935996', recipients=[RENATA_BOLOTOVA], recipient_uncertain=SNEAKY_DOG),
    EmailCfg(id='EFTA01846434', recipients=[RENATA_BOLOTOVA], recipient_uncertain=SNEAKY_DOG, truncate_to=1220),
    EmailCfg(id='EFTA00977447', recipients=[RENATA_BOLOTOVA], recipient_uncertain=SNEAKY_DOG, duplicate_ids=['EFTA02577917', 'EFTA01946045']),
    EmailCfg(id='EFTA01843319', recipients=[RENATA_BOLOTOVA], recipient_uncertain=SNEAKY_DOG, duplicate_ids=['EFTA00929871', 'EFTA01773449', 'EFTA02550388']),
    EmailCfg(id='EFTA00850130', recipients=[SERGEY_BELYAKOV]),
    EmailCfg(id='EFTA00852324', recipients=[SERGEY_BELYAKOV, JEFFREY_EPSTEIN, 'Elena Bolyakina', PETER_THIEL]),
    EmailCfg(id='EFTA00857165', recipients=['Seth Lloyd'], author_reason='quoted reply line'),
    EmailCfg(
        id='EFTA00749241',
        author_reason='widely reported',
        highlight_quote='I loved the torture video',
        recipients=[SULTAN_BIN_SULAYEM],
    ),
    EmailCfg(
        id='EFTA00582171',
        author_reason='addressed to "Umar"',
        duplicate_ids=['EFTA02334771', 'EFTA00581170'],
        recipients=[UMAR_DZHABRAILOV],
    ),
    EmailCfg(id='EFTA00582504', recipients=[UMAR_DZHABRAILOV], author_reason='quoted reply'),
    EmailCfg(id='EFTA02731721', recipients=[USANYS]),
    EmailCfg(id='EFTA02731582', recipients=[USANYS]),
    EmailCfg(id='EFTA02731512', recipients=[USANYS], description=f'specific allegations against {GHISLAINE_MAXWELL}'),
    EmailCfg(id='EFTA00039884', recipients=[USANYS]),
    EmailCfg(id='EFTA02731514', recipients=[USANYS], comment='journal upload followup'),
    EmailCfg(id='EFTA02731511', recipients=[USANYS], comment='journal upload followup'),
    EmailCfg(id='EFTA02731515', recipients=[USANYS], comment='journal upload followup'),
    EmailCfg(id='EFTA02731735', recipients=[USANYS], date='2024-03-04T05:04:00', recipient_uncertain=True),
    EmailCfg(id='EFTA02731715', recipients=[USANYS], duplicate_ids=['EFTA02731762']),
    EmailCfg(id='EFTA02731480', recipients=[USANYS], recipient_uncertain=True),
    EmailCfg(id='EFTA02731482', recipients=[USANYS], recipient_uncertain=True),
    EmailCfg(id='EFTA02731713', recipients=[USANYS], recipient_uncertain=True),
    EmailCfg(id='EFTA02731718', recipients=[USANYS], recipient_uncertain=True),
    EmailCfg(id='EFTA00949295', is_interesting=True),
    EmailCfg(id='EFTA02605815', is_interesting=True, comment='totally tricked out by uncle jeffrey'),
    EmailCfg(id='EFTA02645069', is_interesting=True, description='Epstein says the Mongolians have asked him to create a currency'),
    EmailCfg(id='EFTA02637315', is_interesting=True, description=f"{AZIZA_ALAHMADI} says BTC to fiat is legalized in middle east"),
    EmailCfg(id='EFTA02517037', is_interesting=True, description=f"Epstein wants to talk about Kazakhstan with {LARRY_SUMMERS}"),
    EmailCfg(id='EFTA02559311', is_interesting=True, description=f"Epstein has some connection to the sovereign wealth fund of Kazakhstan"),
    EmailCfg(
        id='EFTA01993032',
        is_interesting=True,
        description=f'{IAN_OSBORNE} calls Greg Craig "my guy", offers to help with visa for woman Epstein "prefers not be part of my file"',
    ),
    EmailCfg(id='EFTA02062130', is_interesting=True, description=f'{NILI_PRIELL_BARAK} installing cameras at Epstein\'s house'),
    EmailCfg(id='EFTA02730481', date='2023-07-07T11:01:00', date_uncertain='actually reply timestamp'),
    EmailCfg(id='EFTA02731577', date='2024-10-16T00:00:00', date_uncertain='actually reply timestamp'),
    # Generated basd on OtherFile.extract_timestamp()
    EmailCfg(id='EFTA00901970', description=f"{AL_SECKEL}'s response to Epstein's forged email", is_interesting=True, truncate_to=3000),
    EmailCfg(id='EFTA02367311', description='Alice Rothschild', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA00992595', description=f"{ARIANE_DE_ROTHSCHILD} mentions her visit to Mongolia"),
    EmailCfg(
        id='EFTA01834864',
        description=f"forged email by Epstein complaining about {AL_SECKEL}'s Mindshift conference",
        is_interesting=True,
    ),
    EmailCfg(id='EFTA02541344', description=f"{BROCK_PIERCE} on marriage and polygamy with people named Crystal and Sue", is_interesting=True),
    EmailCfg(id='EFTA02641951', description=f"{DAVID_STERN} recommends ProtonMail for more secure communications"),
    EmailCfg(id='EFTA00987206', description=f"Epstein helps {BORIS_NIKOLIC} draft an email to {YURI_MILNER}", is_interesting=True),
    EmailCfg(id='EFTA00277107', description=f'FBI tip alleging connections between Wirecard and {GHISLAINE_MAXWELL} network', truncate_to=5500),
    EmailCfg(
        id='EFTA02634615',
        description=f"Indyke says Epstein didn't want his name associated with his investment in {CARBYNE} / Reporty",
        is_interesting=True,
        truncate_to=4000,
    ),
    EmailCfg(id='EFTA02540384', description='Epstein asks for an intro to the bitcoin team he would go on to fund', is_interesting=True),
    EmailCfg(id='EFTA01769169', description='Epstein tells Jean Luc Brunel he can spend up to $25 million', truncate_to=NO_TRUNCATE),
    EmailCfg(
        id='EFTA02483194',
        description=f"fwded email from {GANBAT_CHULUUNKHUU} explaining why he's now wanted by Interpol",
        is_interesting=True,
        show_with_name=GANBAT_CHULUUNKHUU,
    ),
    EmailCfg(
        id='EFTA00039989',
        description=f"ICE has an immigration hold on a man who might have important info about the Epstein case",
        is_interesting=True,
    ),
    # Descriptions
    EmailCfg(
        id='EFTA00339256',
        author=LESLEY_GROFF,
        author_uncertain=True,
        description=f"the (possibly faked) death of {AL_SECKEL}",
        is_interesting=True,
    ),
    EmailCfg(id='EFTA00923902', description=f"Andrey Vavilov offers to buy Epstein's house for $100 million", truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA01175429', description=f"Andrey Vavilov offers to buy Epstein's house for $100 million"),
    EmailCfg(id='EFTA00756577', description=f"{BEN_GOERTZEL} congratulates Epstein on getting out of jail", is_interesting=True, truncate_to=2500),
    EmailCfg(id='EFTA00322570', description=f'booking flight for {REDACTED} from Hong Kong to NYC'),
    EmailCfg(id='EFTA00363992', description=f"car rental for {MARIANA_IDZKOWSKA}"),
    EmailCfg(id='EFTA02630431', description=f"{CARBYNE} is an Israeli company invested in by Epstein, {NICOLE_JUNKERMANN}, & {EHUD_BARAK}"),
    EmailCfg(id='EFTA02573653', description=f'discussion of {PRINCE_ANDREW}\'s Urramoor, "Howard" is probably {HOWARD_LUTNICK} which Urramoor partnered with'),
    EmailCfg(id='EFTA02629771', description=f"discussion of {RENATA_BOLOTOVA}'s employment at IPI", is_interesting=True),
    EmailCfg(id='EFTA00671263', description="Eagle's View Capital Management September 2017 Performance Update"),
    EmailCfg(id='EFTA00836182', description=f'email to investors in {VALAR_FUND}'),
    EmailCfg(id='EFTA00877726', description=f'Epstein and {DAVID_STERN} discuss plans to manage money for wealthy Chinese'),
    EmailCfg(id='EFTA00941197', description=f'Epstein appears to be helping with an investment in Jawbone by {HEDOSOPHIA}'),
    EmailCfg(id='EFTA02592748', description=f"Epstein asks {BROCK_PIERCE} for a favour related to someone named 'Sue'", truncate_to=300),
    EmailCfg(
        id='EFTA01801056',
        description=f'Epstein asks {PETER_MANDELSON} to find him a new assistant, "multi lingaul, 22-25"',
        truncate_to=1200,
    ),
    EmailCfg(id='EFTA00829178', description="Epstein deletes his Instagram account", truncate_to=598, is_interesting=True),
    EmailCfg(id='EFTA00664252', description='Epstein explains his "no wives / no girlfriends" policy', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02689871', description=f"Epstein instructs {DAVID_STERN} to avoid {BANQUE_HAVILLAND}"),
    EmailCfg(id='EFTA00949376', description=f"Epstein paying {MC2_MODEL_MGMT}", truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA01970982', description='Epstein planning a meeting with Vladimir Putin', is_interesting=True),
    EmailCfg(id='EFTA01914954', description='Epstein planning a meeting with Vladimir Putin', is_interesting=True),
    EmailCfg(id='EFTA01060612', description=f"Epstein plots against the JASTA bill"),
    EmailCfg(id='EFTA00630134', description=f'Epstein recommends Signal encrypted messenger to {ALLEGED_KARIM_WADE}', is_interesting=True),
    EmailCfg(id='EFTA00955694', description=f"Epstein thanks {ELON_MUSK} for the SpaceX tour that Musk has said never happened", is_interesting=True),
    EmailCfg(id='EFTA00758094', description='guest list includes Cyrus Vance, Jimmy Buffet, Harvey Weinstein, and more', is_interesting=True),
    EmailCfg(id='EFTA02565917', description='Hassan Mohammed Abdul Latif Jameel is a Saudi businessman and philanthropist'),
    EmailCfg(id='EFTA02277132', description='hotel booking in Kiev'),
    EmailCfg(id='EFTA00927227', description=f"{IAN_OSBORNE} pitches his new venture fund {HEDOSOPHIA} to Epstein", is_interesting=True),
    EmailCfg(id='EFTA01756112', description=f'{JOI_ITO} plays down Epstein\'s "jail thing"'),
    EmailCfg(id='EFTA01767036', description=f'"Karim" is probably {ALLEGED_KARIM_WADE}'),
    EmailCfg(id='EFTA02515416', description=f'{JEAN_LUC_BRUNEL} is having visa problems', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02513560', description=f"{JEAN_LUC_BRUNEL} doesn't want to speak on the phone", truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02671523', description=f"Jones is former Google chief technology advocate / CEO of Epstein investment Wearality"),
    EmailCfg(id='EFTA02464628', description=f"{KATHRYN_RUEMMLER} and Epstein on {JEAN_LUC_BRUNEL}'s immunity deal (for Epstein testimony?)", is_interesting=True),
    EmailCfg(id='EFTA01854384', description=f"{KARIM_WADE} asks if Epstein is free to meet the president (of Senegal?)", truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA00080250', description=f"{LEON_BLACK} / Rothschild Group {DEUTSCHE_BANK} transactions", is_interesting=True),
    EmailCfg(id='EFTA02455633', description=f"{MASHA_DROKOVA} loves WeWork", truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA01958867', description=f'"Mr. T" is {PRINCE_ANDREW}, "Howard" is {HOWARD_LUTNICK}'),
    EmailCfg(id='EFTA00771388', description=f"{NAOMI_CAMPBELL} seems to have made some introductions to Russian oligarchs"),
    EmailCfg(id='EFTA00754450', description='"PA" is probably Prince Andrew', duplicate_ids=['EFTA02418244']),
    EmailCfg(id='EFTA02415612', description='party invite from Doronin', is_interesting=True),
    EmailCfg(id='EFTA02087543', description="password for Epstein's RingCentral home security system", is_interesting=True, truncate_to=500),
    EmailCfg(id='EFTA01003346', description=f"{PETER_THIEL} tells Epstein to invest in his fund", is_interesting=True),
    EmailCfg(id='EFTA02014739', description='phishing attack on a Yahoo account "jeffrey.epstein"', is_interesting=True, truncate_to=700),
    EmailCfg(id='EFTA02561277', description=f"planning for {ELON_MUSK} gets a massage", is_interesting=True),
    EmailCfg(id='EFTA00364437', description='planning a trip to the Ivory Coast', is_interesting=True, truncate_to=2_000),
    EmailCfg(id='EFTA00758140', description="possibly about Sarah Ferguson?"),
    EmailCfg(id='EFTA01013413', description='Reza Bundy is the founder of IronPlanet'),
    EmailCfg(id='EFTA02339109', description=f'someone named Sue needs help (probably a sham marriage to {BROCK_PIERCE}, see later emails)'),
    EmailCfg(id='EFTA01764152', description=f"thoughts on {STEVEN_SINOFSKY} joining a16z (which he later did)"),
    EmailCfg(id='EFTA00532500', description=f"visa applications for Russia, Belarus, and Kazakhstan", is_interesting=True, truncate_to=420),
    EmailCfg(id='EFTA02412854', description=f'who\'s "D>>>" and what does he have to be careful about?'),
    EmailCfg(id='EFTA02353279', description=f'why is a frenchman like {JEAN_LUC_BRUNEL} "normally in Israel"?'),
    EmailCfg(id='EFTA02633194', description=f'{NICOLE_JUNKERMANN} quotes an appraisal by "FSB (Russians)"', is_interesting=True),
    EmailCfg(id='EFTA00826876', description=f"Epstein offers to help pay for {PETER_THIEL}'s lawsuit against Gawker"),
    EmailCfg(
        id='EFTA01882985',
        description=f'Epstein: "yuri money is russian gangster money, Usmanov" ("Steve" is likely {STEVEN_SINOFSKY})',
        is_interesting=True,
        recipients=[MELANIE_PHILLIPS],
        recipient_uncertain='maybe Boris Nikolic but Boris asks Epstein same question a few months later',
    ),
    EmailCfg(id='EFTA00039888', date='2019-05-14 16:49:00'),
    EmailCfg(id='EFTA00040145', date='2021-11-09 17:24:30'),
    EmailCfg(id='EFTA02730485', date='2021-12-03 00:00:00'),
    EmailCfg(id='EFTA01858685', is_interesting=True, comment='Boris asks about Stanley Ho (maybe)'),

    # Duplicates
    EmailCfg(id='EFTA00875181', duplicate_ids=['EFTA01901268']),
    EmailCfg(id='EFTA01852975', duplicate_ids=['EFTA02001764']),
    EmailCfg(id='EFTA00563586', duplicate_ids=['EFTA02323722']),
    EmailCfg(id='EFTA00039802', duplicate_ids=['EFTA00039809']),
    EmailCfg(id='EFTA01002234', duplicate_ids=['EFTA02597754']),
    EmailCfg(id='EFTA00039799', duplicate_ids=['EFTA00039806']),
    EmailCfg(id='EFTA02608800', duplicate_ids=['EFTA01010308']),
    EmailCfg(id='EFTA00870649', duplicate_ids=['EFTA01932408']),
    EmailCfg(id='EFTA00717931', duplicate_ids=['EFTA01774218']),
    EmailCfg(id='EFTA02390441', duplicate_ids=['EFTA02403336']),
    EmailCfg(id='EFTA00428083', duplicate_ids=['EFTA02183761']),
    EmailCfg(id='EFTA00432350', duplicate_ids=['EFTA02187050']),
    EmailCfg(id='EFTA00432352', duplicate_ids=['EFTA02187120']),
    EmailCfg(id='EFTA00373948', duplicate_ids=['EFTA02113506']),
    EmailCfg(id='EFTA00870717', duplicate_ids=['EFTA01932706']),
    EmailCfg(id='EFTA00494141', duplicate_ids=['EFTA02284036'], is_interesting=False),
    EmailCfg(id='EFTA01890312', duplicate_ids=['EFTA00712715'], truncate_to=400),
    EmailCfg(id='EFTA00915302', duplicate_ids=['EFTA01860910', 'EFTA01986221', 'EFTA01776411', 'EFTA02691069']),
    EmailCfg(id='EFTA01776613', duplicate_ids=['EFTA01860812', 'EFTA00915297', 'EFTA02691059']),

    # Truncations
    EmailCfg(id='EFTA00982094', truncate_to=250),
    EmailCfg(id='EFTA00915298', truncate_to=300),
    EmailCfg(id='EFTA00915300', truncate_to=250),
    EmailCfg(id='EFTA00847613', truncate_to=320),
    EmailCfg(id='EFTA00982864', truncate_to=350),
    EmailCfg(id='EFTA00982451', truncate_to=400),
    EmailCfg(id='EFTA01917472', truncate_to=400),
    EmailCfg(id='EFTA01061414', truncate_to=440),
    EmailCfg(id='EFTA02493582', truncate_to=450),
    EmailCfg(id='EFTA00675069', truncate_to=478),
    EmailCfg(id='EFTA00982818', truncate_to=500),
    EmailCfg(id='EFTA01731638', truncate_to=530),
    EmailCfg(id='EFTA00398724', truncate_to=700),
    EmailCfg(id='EFTA00362171', truncate_to=1096),
    EmailCfg(id='EFTA02606529', truncate_to=1500),
    EmailCfg(id='EFTA00836570', truncate_to=1600),
    EmailCfg(id='EFTA00859299', truncate_to=2000),
    EmailCfg(id='EFTA00681240', truncate_to=2000),
    EmailCfg(id='EFTA00669647', truncate_to=2500),
    EmailCfg(id='EFTA02374977', truncate_to=2500),
    EmailCfg(id='EFTA00700415', truncate_to=DEFAULT_TRUNCATE_TO),
    EmailCfg(id='EFTA00869828', truncate_to=SHORT_TRUNCATE_TO),
    EmailCfg(id='EFTA00875591', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA00959952', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA01010114', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA01903448', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA00661348', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02378915', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA00676383', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02628058', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA02626427', truncate_to=NO_TRUNCATE),
    EmailCfg(id='EFTA01880345', author=SHAHER_ABDULHAK_BESHER),
    shaher_murder_email('EFTA02021096'),
    shaher_murder_email('EFTA00937008', author=SHAHER_ABDULHAK_BESHER, author_reason='Etislat signature'),
    shaher_murder_email('EFTA01878623', author=SHAHER_ABDULHAK_BESHER, author_reason='"S A" + "your son"', description='khat is a Yemeni drug,'),

    #### MAGIC COMMENT FOR MANUAL CONFIG ####
    EmailCfg(
        id='EFTA02581361',
        description='Epstein funded a conference in Cuba that Gino Yu put together with $100k',
        is_interesting=True,
        truncate_to=NO_TRUNCATE,
    ),
    EmailCfg(id='EFTA02641374', is_interesting=True),
    # EmailCfg(id='EFTA02641374', is_interesting=True),
    EmailCfg(id='EFTA01848168', show_with_name=CHRIS_POOLE),
    EmailCfg(id='EFTA01849797', show_with_name=CHRIS_POOLE),
    EmailCfg(id='EFTA02179653', show_with_name=CHRIS_POOLE),
    EmailCfg(id='EFTA01987383', show_with_name=CHRIS_POOLE),
    EmailCfg(id='EFTA00718804', non_participants=[MILES_GUO]),
    EmailCfg(id='EFTA00932122', non_participants=[MILES_GUO]),
    EmailCfg(id='EFTA00909508', comment='party at Bunker'),

    # DropSite emails
    EmailCfg(
        id='DropSite 2002-12-07 1015',
        description=f'draft (?) of email to Graydon Carter to get the assault allegations spiked from Vikcy Ward\'s Vanity Fair profile',
    ),
]
